@@ -25,7 +25,7 @@ import xml.dom.minidom
 # SET VERSION
 # -----------
 
-version = '5.0.1'
+version = '5.1.0'
 nightbuild = ''
 
 
@@ -67,7 +67,7 @@ internal={
 }
 
 main={
-    'appWidth': 1043,
+    'appWidth': 1050,
     'appHeight': 620,
     'appMaximized': 0,
     'unlockGUI': 0,
@@ -310,6 +310,7 @@ massCalculator={
     'patternShift': 0,
     'patternThreshold': 0.001,
     'patternShowPeaks': 1,
+    'patternPeakShape': 'gaussian',
 }
 
 massfilter={}
@@ -322,6 +323,7 @@ massToFormula={
     'formulaMin': '',
     'formulaMax': '',
     'autoCHNO': 1,
+    'checkPattern': 1,
     'limit': 1000,
     'rules': ['HC','NOPSC','NOPS','RDBE', 'RDBEInt'],
     'HCMin': 0.1,
@@ -351,14 +353,17 @@ peakDifferences={
     'dipeptides': 1,
     'massType': 0,
     'tolerance': 0.1,
-    'showAll': 1,
+    'consolidate': 0,
 }
 
 comparePeaklists={
+    'compare': 'peaklists',
     'tolerance': 0.2,
     'units': 'Da',
     'ignoreCharge': 0,
-    'compare': 'peaklists',
+    'ratioCheck': 0,
+    'ratioDirection': 1,
+    'ratioThreshold': 2,
 }
 
 spectrumGenerator={
@@ -366,6 +371,7 @@ spectrumGenerator={
     'points': 10,
     'noise': 0,
     'forceFwhm': 0,
+    'peakShape': 'gaussian',
     'showPeaks': 1,
     'showOverlay': 0,
     'showFlipped': 0,
@@ -380,6 +386,7 @@ envelopeFit={
     'charge': 1,
     'fwhm': 0.01,
     'forceFwhm': 0,
+    'peakShape': 'gaussian',
     'autoAlign': 1,
     'relThreshold': 0.05,
 }
@@ -1053,6 +1060,7 @@ def saveConfig(path=os.path.join(confdir, 'config.xml')):
     buff += '    <param name="patternFwhm" value="%f" type="float" />\n' % (massCalculator['patternFwhm'])
     buff += '    <param name="patternThreshold" value="%f" type="float" />\n' % (massCalculator['patternThreshold'])
     buff += '    <param name="patternShowPeaks" value="%d" type="int" />\n' % (bool(massCalculator['patternShowPeaks']))
+    buff += '    <param name="patternPeakShape" value="%s" type="unicode" />\n' % (_escape(massCalculator['patternPeakShape']))
     buff += '  </massCalculator>\n\n'
     
     # mass to formula
@@ -1064,6 +1072,7 @@ def saveConfig(path=os.path.join(confdir, 'config.xml')):
     buff += '    <param name="formulaMin" value="%s" type="str" />\n' % (massToFormula['formulaMin'])
     buff += '    <param name="formulaMax" value="%s" type="str" />\n' % (massToFormula['formulaMax'])
     buff += '    <param name="autoCHNO" value="%d" type="int" />\n' % (bool(massToFormula['autoCHNO']))
+    buff += '    <param name="checkPattern" value="%d" type="int" />\n' % (bool(massToFormula['checkPattern']))
     buff += '    <param name="limit" value="%d" type="int" />\n' % (massToFormula['limit'])
     buff += '    <param name="rules" value="%s" type="str" />\n' % (';'.join(massToFormula['rules']))
     buff += '    <param name="HCMin" value="%f" type="float" />\n' % (massToFormula['HCMin'])
@@ -1095,7 +1104,7 @@ def saveConfig(path=os.path.join(confdir, 'config.xml')):
     buff += '    <param name="dipeptides" value="%d" type="int" />\n' % (bool(peakDifferences['dipeptides']))
     buff += '    <param name="tolerance" value="%f" type="float" />\n' % (peakDifferences['tolerance'])
     buff += '    <param name="massType" value="%d" type="int" />\n' % (peakDifferences['massType'])
-    buff += '    <param name="showAll" value="%d" type="int" />\n' % (bool(peakDifferences['showAll']))
+    buff += '    <param name="consolidate" value="%d" type="int" />\n' % (bool(peakDifferences['consolidate']))
     buff += '  </peakDifferences>\n\n'
     
     # compare peaklists
@@ -1103,6 +1112,9 @@ def saveConfig(path=os.path.join(confdir, 'config.xml')):
     buff += '    <param name="tolerance" value="%f" type="float" />\n' % (comparePeaklists['tolerance'])
     buff += '    <param name="units" value="%s" type="str" />\n' % (comparePeaklists['units'])
     buff += '    <param name="ignoreCharge" value="%d" type="int" />\n' % (bool(comparePeaklists['ignoreCharge']))
+    buff += '    <param name="ratioCheck" value="%d" type="int" />\n' % (bool(comparePeaklists['ratioCheck']))
+    buff += '    <param name="ratioDirection" value="%d" type="int" />\n' % (comparePeaklists['ratioDirection'])
+    buff += '    <param name="ratioThreshold" value="%f" type="float" />\n' % (comparePeaklists['ratioThreshold'])
     buff += '  </comparePeaklists>\n\n'
     
     # spectrum generator
@@ -1111,6 +1123,7 @@ def saveConfig(path=os.path.join(confdir, 'config.xml')):
     buff += '    <param name="points" value="%d" type="int" />\n' % (spectrumGenerator['points'])
     buff += '    <param name="noise" value="%f" type="float" />\n' % (spectrumGenerator['noise'])
     buff += '    <param name="forceFwhm" value="%d" type="int" />\n' % (bool(spectrumGenerator['forceFwhm']))
+    buff += '    <param name="peakShape" value="%s" type="unicode" />\n' % (_escape(spectrumGenerator['peakShape']))
     buff += '    <param name="showPeaks" value="%d" type="int" />\n' % (bool(spectrumGenerator['showPeaks']))
     buff += '    <param name="showOverlay" value="%d" type="int" />\n' % (bool(spectrumGenerator['showOverlay']))
     buff += '  </spectrumGenerator>\n\n'
@@ -1120,6 +1133,7 @@ def saveConfig(path=os.path.join(confdir, 'config.xml')):
     buff += '    <param name="fit" value="%s" type="str" />\n' % (envelopeFit['fit'])
     buff += '    <param name="fwhm" value="%f" type="float" />\n' % (envelopeFit['fwhm'])
     buff += '    <param name="forceFwhm" value="%d" type="int" />\n' % (bool(envelopeFit['forceFwhm']))
+    buff += '    <param name="peakShape" value="%s" type="unicode" />\n' % (_escape(envelopeFit['peakShape']))
     buff += '    <param name="autoAlign" value="%d" type="int" />\n' % (bool(envelopeFit['autoAlign']))
     buff += '    <param name="relThreshold" value="%f" type="float" />\n' % (envelopeFit['relThreshold'])
     buff += '  </envelopeFit>\n\n'
