@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -52,7 +52,7 @@ class dlgReferencesEditor(wx.Dialog):
         
         # show data
         self.updateGroups()
-        self.groupName_combo.Select(0)
+        self.groupName_choice.Select(0)
     # ----
     
     
@@ -78,8 +78,8 @@ class dlgReferencesEditor(wx.Dialog):
         """Make group editor."""
         
         # make elements
-        self.groupName_combo = wx.ComboBox(self, -1, size=(-1, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.groupName_combo.Bind(wx.EVT_COMBOBOX, self.onGroupSelected)
+        self.groupName_choice = wx.Choice(self, -1, size=(-1, mwx.CHOICE_HEIGHT))
+        self.groupName_choice.Bind(wx.EVT_CHOICE, self.onGroupSelected)
         
         groupImport_butt = wx.Button(self, -1, "Import")
         groupImport_butt.Bind(wx.EVT_BUTTON, self.onImport)
@@ -95,7 +95,7 @@ class dlgReferencesEditor(wx.Dialog):
         
         # pack elements
         sizer = wx.BoxSizer(wx.HORIZONTAL)
-        sizer.Add(self.groupName_combo, 1, wx.RIGHT|wx.ALIGN_CENTER_VERTICAL, 30)
+        sizer.Add(self.groupName_choice, 1, wx.RIGHT|wx.ALIGN_CENTER_VERTICAL, 30)
         sizer.Add(groupImport_butt, 0, wx.RIGHT, 15)
         sizer.Add(groupNew_butt, 0, wx.RIGHT, 15)
         sizer.Add(groupRename_butt, 0, wx.RIGHT, 15)
@@ -166,7 +166,7 @@ class dlgReferencesEditor(wx.Dialog):
         """Update items for selected group."""
         
         # get selected group
-        group = self.groupName_combo.GetValue()
+        group = self.groupName_choice.GetStringSelection()
         if group in libs.references:
             self.group = group
         else:
@@ -254,7 +254,7 @@ class dlgReferencesEditor(wx.Dialog):
         
         # update gui
         self.updateGroups()
-        self.groupName_combo.SetValue(selectAfter)
+        self.groupName_choice.SetStringSelection(selectAfter)
         self.onGroupSelected()
     # ----
     
@@ -284,7 +284,7 @@ class dlgReferencesEditor(wx.Dialog):
         
         # update gui
         self.updateGroups()
-        self.groupName_combo.SetValue(name)
+        self.groupName_choice.SetStringSelection(name)
         self.onGroupSelected()
     # ----
     
@@ -323,7 +323,7 @@ class dlgReferencesEditor(wx.Dialog):
         
         # update gui
         self.updateGroups()
-        self.groupName_combo.SetValue(name)
+        self.groupName_choice.SetStringSelection(name)
         self.onGroupSelected()
     # ----
     
@@ -352,7 +352,7 @@ class dlgReferencesEditor(wx.Dialog):
         
         # update gui
         self.updateGroups()
-        self.groupName_combo.Select(0)
+        self.groupName_choice.Select(0)
         self.onGroupSelected()
     # ----
     
@@ -405,9 +405,7 @@ class dlgReferencesEditor(wx.Dialog):
             indexes.append(index)
         
         # delete items
-        indexes.sort()
-        indexes.reverse()
-        for i in indexes:
+        for i in sorted(indexes, reverse=True):
             del libs.references[self.group][i]
         
         # update gui
@@ -420,7 +418,7 @@ class dlgReferencesEditor(wx.Dialog):
         """Update groups combo."""
         
         # clear groups
-        self.groupName_combo.Clear()
+        self.groupName_choice.Clear()
         
         # get names
         choices = sorted(libs.references.keys())
@@ -428,7 +426,7 @@ class dlgReferencesEditor(wx.Dialog):
         
         # add names
         for choice in choices:
-            self.groupName_combo.Append(choice)
+            self.groupName_choice.Append(choice)
     # ----
     
     
