@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 #load libs
@@ -200,7 +200,7 @@ class document():
         # format spectrum
         precision = config.main['dataPrecision']
         endian = sys.byteorder
-        points = self.spectrum.points
+        points = self.spectrum.profile
         mzArray, intArray = self._convertSpectrum(points, precision)
         attributes = 'points="%s"' % len(points)
         if self.spectrum.scanNumber != None:
@@ -338,7 +338,7 @@ class document():
         msLevel = ''
         precursorMZ = ''
         polarity = 'unknown'
-        points = len(self.spectrum.points)
+        points = len(self.spectrum.profile)
         peaks = len(self.spectrum.peaklist)
         
         basePeak = self.spectrum.peaklist.basepeak
@@ -606,6 +606,10 @@ class document():
             # format position
             if type(mod[1]) == int:
                 position = '%s %s' % (sequence[mod[1]], mod[1]+1)
+            elif mod[1] == 'nTerm':
+                position = 'N-terminus'
+            elif mod[1] == 'cTerm':
+                position = 'C-terminus'
             else:
                 position = 'All ' + mod[1]
             
@@ -723,7 +727,7 @@ class annotation():
     def delta(self, units):
         """Get error in specified units."""
         
-        if self.theoretical != None :
+        if self.theoretical != None:
             return mspy.delta(self.mz, self.theoretical, units)
         else:
             return None
@@ -984,7 +988,7 @@ class parseMSD():
             points = points.copy()
             
             # add to spectrum
-            self.document.spectrum.setPoints(points)
+            self.document.spectrum.setprofile(points)
     # ----
     
     
@@ -1036,7 +1040,7 @@ class parseMSD():
         
         # add peaklist to document
         peaklist = mspy.peaklist(peaklist)
-        self.document.spectrum.setPeaklist(peaklist)
+        self.document.spectrum.setpeaklist(peaklist)
     # ----
     
     
@@ -1267,7 +1271,7 @@ class parseMSD():
         
         # add peaklist to document
         peaklist = mspy.peaklist(peaklist)
-        self.document.spectrum.setPeaklist(peaklist)
+        self.document.spectrum.setpeaklist(peaklist)
     # ----
     
     
@@ -1334,7 +1338,7 @@ class parseMSD():
     
     
     
-    # UTILITIES
+    # HELPERS
     
     def _convertDataPoints(self, data, compression, precision='f', endian='<'):
         """Convert spectrum data points."""
@@ -1455,7 +1459,7 @@ REPORT_HEADER = """<?xml version="1.0" encoding="utf-8"?>
     html>body th, html>body td{font-size: .9em;}
     th{text-align: center; color: #000; background-color: #ccc;}
     th a{text-align: center; color: #000; background-color: #ccc; text-decoration: none;}
-    #tableMainInfo th{text-align: right; width: 20%;}
+    #tableMainInfo th{text-align: right; width: 15%;}
     #tableMainInfo td{text-align: left;}
     #spectrum{text-align: center;}
     #footer{font-size: .8em; font-style: italic; text-align: center; color: #aaa; margin: 2em 0 1em 0; padding-top: 0.5em; border-top: 1px solid #000;}
