@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -115,6 +115,7 @@ def loadImages():
     lib['bgrToolbar'] = images_lib.getBgrToolbarBitmap()
     lib['bgrToolbarNoBorder'] = images_lib.getBgrToolbarNoBorderBitmap()
     lib['bgrControlbar'] = images_lib.getBgrControlbarBitmap()
+    lib['bgrControlbarBorder'] = images_lib.getBgrControlbarBorderBitmap()
     lib['bgrControlbarDouble'] = images_lib.getBgrControlbarDoubleBitmap()
     lib['bgrBottombar'] = images_lib.getBgrBottombarBitmap()
     lib['bgrPeakEditor'] = images_lib.getBgrPeakEditorBitmap()
@@ -133,23 +134,26 @@ def loadImages():
     # tools
     if wx.Platform == '__WXMAC__':
         tools = images_lib.getToolsBitmap()
-        lib['toolsProcessing'] = tools.GetSubBitmap(wx.Rect(0, 0, 30, 23))
-        lib['toolsCalibration'] = tools.GetSubBitmap(wx.Rect(30, 0, 30, 23))
-        lib['toolsSequence'] = tools.GetSubBitmap(wx.Rect(60, 0, 30, 23))
-        lib['toolsMassCalculator'] = tools.GetSubBitmap(wx.Rect(90, 0, 30, 23))
-        lib['toolsCompoundsSearch'] = tools.GetSubBitmap(wx.Rect(120, 0, 30, 23))
-        lib['toolsPeakDifferences'] = tools.GetSubBitmap(wx.Rect(150, 0, 30, 23))
-        lib['toolsComparePeaklists'] = tools.GetSubBitmap(wx.Rect(180, 0, 30, 23))
-        lib['toolsMascot'] = tools.GetSubBitmap(wx.Rect(210, 0, 30, 23))
-        lib['toolsProfound'] = tools.GetSubBitmap(wx.Rect(240, 0, 30, 23))
-        lib['toolsDocumentInfo'] = tools.GetSubBitmap(wx.Rect(270, 0, 30, 23))
-        lib['toolsDocumentReport'] = tools.GetSubBitmap(wx.Rect(300, 0, 30, 23))
-        lib['toolsDocumentExport'] = tools.GetSubBitmap(wx.Rect(330, 0, 30, 23))
-        lib['toolsPresets'] = tools.GetSubBitmap(wx.Rect(360, 0, 30, 22))
-        lib['toolsMassFilter'] = tools.GetSubBitmap(wx.Rect(390, 0, 30, 23))
-        lib['toolsSpectrumGenerator'] = tools.GetSubBitmap(wx.Rect(420, 0, 30, 23))
-        lib['toolsEnvelopeFit'] = tools.GetSubBitmap(wx.Rect(450, 0, 30, 23))
-        lib['toolsLibrary'] = tools.GetSubBitmap(wx.Rect(480, 0, 30, 22))
+        lib['toolsProcessing'] = tools.GetSubBitmap(wx.Rect(0, 5, 32, 23))
+        lib['toolsCalibration'] = tools.GetSubBitmap(wx.Rect(32, 5, 32, 23))
+        lib['toolsSequence'] = tools.GetSubBitmap(wx.Rect(64, 5, 32, 23))
+        lib['toolsMassCalculator'] = tools.GetSubBitmap(wx.Rect(96, 5, 32, 23))
+        lib['toolsCompoundsSearch'] = tools.GetSubBitmap(wx.Rect(128, 5, 32, 23))
+        lib['toolsPeakDifferences'] = tools.GetSubBitmap(wx.Rect(160, 5, 32, 23))
+        lib['toolsComparePeaklists'] = tools.GetSubBitmap(wx.Rect(192, 5, 32, 23))
+        lib['toolsMascot'] = tools.GetSubBitmap(wx.Rect(224, 5, 32, 23))
+        lib['toolsProfound'] = tools.GetSubBitmap(wx.Rect(256, 5, 32, 23))
+        lib['toolsDocumentInfo'] = tools.GetSubBitmap(wx.Rect(288, 5, 32, 23))
+        lib['toolsDocumentReport'] = tools.GetSubBitmap(wx.Rect(320, 5, 32, 23))
+        lib['toolsDocumentExport'] = tools.GetSubBitmap(wx.Rect(352, 5, 32, 23))
+        lib['toolsMassFilter'] = tools.GetSubBitmap(wx.Rect(384, 5, 32, 23))
+        lib['toolsSpectrumGenerator'] = tools.GetSubBitmap(wx.Rect(416, 5, 32, 23))
+        lib['toolsEnvelopeFit'] = tools.GetSubBitmap(wx.Rect(448, 5, 32, 23))
+        lib['toolsMassToFormula'] = tools.GetSubBitmap(wx.Rect(480, 5, 32, 23))
+        lib['toolsPeriodicTable'] = tools.GetSubBitmap(wx.Rect(512, 5, 32, 23))
+        
+        lib['toolsPresets'] = tools.GetSubBitmap(wx.Rect(0, 37, 32, 22))
+        lib['toolsLibrary'] = tools.GetSubBitmap(wx.Rect(32, 37, 32, 22))
     else:
         tools = images_lib.getToolsBitmap()
         lib['toolsOpen'] = tools.GetSubBitmap(wx.Rect(0, 0, 22, 22))
@@ -172,6 +176,8 @@ def loadImages():
         lib['toolsSpectrumGenerator'] = tools.GetSubBitmap(wx.Rect(374, 0, 22, 22))
         lib['toolsEnvelopeFit'] = tools.GetSubBitmap(wx.Rect(396, 0, 22, 22))
         lib['toolsLibrary'] = tools.GetSubBitmap(wx.Rect(418, 0, 22, 22))
+        lib['toolsMassToFormula'] = tools.GetSubBitmap(wx.Rect(440, 0, 22, 22))
+        lib['toolsPeriodicTable'] = tools.GetSubBitmap(wx.Rect(462, 0, 22, 22))
     
     # bottombars
     bottombarsOn = images_lib.getBottombarsOnBitmap()
@@ -276,6 +282,8 @@ def loadImages():
     lib['processingDeisotopingOff'] = toolbarsOff.GetSubBitmap(wx.Rect(145, 132, 29, 22))
     lib['processingDeconvolutionOn'] = toolbarsOn.GetSubBitmap(wx.Rect(174, 132, 29, 22))
     lib['processingDeconvolutionOff'] = toolbarsOff.GetSubBitmap(wx.Rect(174, 132, 29, 22))
+    lib['processingBatchOn'] = toolbarsOn.GetSubBitmap(wx.Rect(203, 132, 29, 22))
+    lib['processingBatchOff'] = toolbarsOff.GetSubBitmap(wx.Rect(203, 132, 29, 22))
     
     lib['sequenceEditorOn'] = toolbarsOn.GetSubBitmap(wx.Rect(0, 154, 29, 22))
     lib['sequenceEditorOff'] = toolbarsOff.GetSubBitmap(wx.Rect(0, 154, 29, 22))
@@ -646,41 +654,42 @@ def convertImages():
         
         # make commands
         commands = [
-            "-a -u -i -n Icon16 images/"+platform+"/icon_16.png images_lib_"+platform+".py",
-            "-a -u -i -n Icon32 images/"+platform+"/icon_32.png images_lib_"+platform+".py",
-            "-a -u -i -n Icon48 images/"+platform+"/icon_48.png images_lib_"+platform+".py",
-            "-a -u -i -n Icon128 images/"+platform+"/icon_128.png images_lib_"+platform+".py",
-            "-a -u -i -n Icon256 images/"+platform+"/icon_256.png images_lib_"+platform+".py",
-            "-a -u -i -n Icon512 images/"+platform+"/icon_512.png images_lib_"+platform+".py",
+            "-f -a -u -i -n Icon16 images/"+platform+"/icon_16.png images_lib_"+platform+".py",
+            "-f -a -u -i -n Icon32 images/"+platform+"/icon_32.png images_lib_"+platform+".py",
+            "-f -a -u -i -n Icon48 images/"+platform+"/icon_48.png images_lib_"+platform+".py",
+            "-f -a -u -i -n Icon128 images/"+platform+"/icon_128.png images_lib_"+platform+".py",
+            "-f -a -u -i -n Icon256 images/"+platform+"/icon_256.png images_lib_"+platform+".py",
+            "-f -a -u -i -n Icon512 images/"+platform+"/icon_512.png images_lib_"+platform+".py",
             
-            "-a -u -n IconAbout images/"+platform+"/icon_about.png images_lib_"+platform+".py",
-            "-a -u -n IconError images/"+platform+"/icon_error.png images_lib_"+platform+".py",
-            "-a -u -n IconDlg images/"+platform+"/icon_dlg.png images_lib_"+platform+".py",
+            "-f -a -u -n IconAbout images/"+platform+"/icon_about.png images_lib_"+platform+".py",
+            "-f -a -u -n IconError images/"+platform+"/icon_error.png images_lib_"+platform+".py",
+            "-f -a -u -n IconDlg images/"+platform+"/icon_dlg.png images_lib_"+platform+".py",
             
-            "-a -u -n Stopper images/"+platform+"/stopper.png images_lib_"+platform+".py",
-            "-a -u -n Cursors images/"+platform+"/cursors.png images_lib_"+platform+".py",
-            "-a -u -n Arrows images/"+platform+"/arrows.png images_lib_"+platform+".py",
+            "-f -a -u -n Stopper images/"+platform+"/stopper.png images_lib_"+platform+".py",
+            "-f -a -u -n Cursors images/"+platform+"/cursors.png images_lib_"+platform+".py",
+            "-f -a -u -n Arrows images/"+platform+"/arrows.png images_lib_"+platform+".py",
             
-            "-a -u -n BgrToolbar images/"+platform+"/bgr_toolbar.png images_lib_"+platform+".py",
-            "-a -u -n BgrToolbarNoBorder images/"+platform+"/bgr_toolbar_noborder.png images_lib_"+platform+".py",
-            "-a -u -n BgrControlbar images/"+platform+"/bgr_controlbar.png images_lib_"+platform+".py",
-            "-a -u -n BgrControlbarDouble images/"+platform+"/bgr_controlbar_double.png images_lib_"+platform+".py",
-            "-a -u -n BgrBottombar images/"+platform+"/bgr_bottombar.png images_lib_"+platform+".py",
-            "-a -u -n BgrPeakEditor images/"+platform+"/bgr_peakeditor.png images_lib_"+platform+".py",
+            "-f -a -u -n BgrToolbar images/"+platform+"/bgr_toolbar.png images_lib_"+platform+".py",
+            "-f -a -u -n BgrToolbarNoBorder images/"+platform+"/bgr_toolbar_noborder.png images_lib_"+platform+".py",
+            "-f -a -u -n BgrControlbar images/"+platform+"/bgr_controlbar.png images_lib_"+platform+".py",
+            "-f -a -u -n BgrControlbarBorder images/"+platform+"/bgr_controlbar_border.png images_lib_"+platform+".py",
+            "-f -a -u -n BgrControlbarDouble images/"+platform+"/bgr_controlbar_double.png images_lib_"+platform+".py",
+            "-f -a -u -n BgrBottombar images/"+platform+"/bgr_bottombar.png images_lib_"+platform+".py",
+            "-f -a -u -n BgrPeakEditor images/"+platform+"/bgr_peakeditor.png images_lib_"+platform+".py",
             
-            "-a -u -n BulletsOn images/"+platform+"/bullets_on.png images_lib_"+platform+".py",
-            "-a -u -n BulletsOff images/"+platform+"/bullets_off.png images_lib_"+platform+".py",
+            "-f -a -u -n BulletsOn images/"+platform+"/bullets_on.png images_lib_"+platform+".py",
+            "-f -a -u -n BulletsOff images/"+platform+"/bullets_off.png images_lib_"+platform+".py",
             
-            "-a -u -n Tools images/"+platform+"/tools.png images_lib_"+platform+".py",
+            "-f -a -u -n Tools images/"+platform+"/tools.png images_lib_"+platform+".py",
             
-            "-a -u -n BottombarsOn images/"+platform+"/bottombars_on.png images_lib_"+platform+".py",
-            "-a -u -n BottombarsOff images/"+platform+"/bottombars_off.png images_lib_"+platform+".py",
-            "-a -u -n ToolbarsOn images/"+platform+"/toolbars_on.png images_lib_"+platform+".py",
-            "-a -u -n ToolbarsOff images/"+platform+"/toolbars_off.png images_lib_"+platform+".py",
+            "-f -a -u -n BottombarsOn images/"+platform+"/bottombars_on.png images_lib_"+platform+".py",
+            "-f -a -u -n BottombarsOff images/"+platform+"/bottombars_off.png images_lib_"+platform+".py",
+            "-f -a -u -n ToolbarsOn images/"+platform+"/toolbars_on.png images_lib_"+platform+".py",
+            "-f -a -u -n ToolbarsOff images/"+platform+"/toolbars_off.png images_lib_"+platform+".py",
             
-            "-a -u -n PtableOn images/"+platform+"/periodic_table_on.png images_lib_"+platform+".py",
-            "-a -u -n PtableOff images/"+platform+"/periodic_table_off.png images_lib_"+platform+".py",
-            "-a -u -n PtableSel images/"+platform+"/periodic_table_sel.png images_lib_"+platform+".py",
+            "-f -a -u -n PtableOn images/"+platform+"/periodic_table_on.png images_lib_"+platform+".py",
+            "-f -a -u -n PtableOff images/"+platform+"/periodic_table_off.png images_lib_"+platform+".py",
+            "-f -a -u -n PtableSel images/"+platform+"/periodic_table_sel.png images_lib_"+platform+".py",
         ]
         
         # convert images
