@@ -85,6 +85,7 @@ SEQUENCE_FONT_SIZE = 10
 PERIODIC_TABLE_GRID = (2,2)
 PERIODIC_TABLE_FONT_SIZE = 14
 DASHED_LINE = wx.SHORT_DASH
+SCROLL_DIRECTION = 1
 
 
 # set mac
@@ -185,6 +186,9 @@ def appInit():
     if wx.Platform == '__WXMAC__':
         wx.SystemOptions.SetOptionInt("mac.listctrl.always_use_generic", config.main['macListCtrlGeneric'])
         wx.ToolTip.SetDelay(1500)
+        if config.main['reverseScrolling']:
+            global SCROLL_DIRECTION
+            SCROLL_DIRECTION = -1
     
     # set WIN
     elif wx.Platform == '__WXMSW__':
@@ -209,7 +213,7 @@ class bgrPanel(wx.Panel):
         
         self.image = image
         
-        # set paint event to title image
+        # set paint event to tile image
         wx.EVT_PAINT(self, self._onPaint)
     # ----
     
@@ -542,7 +546,7 @@ class scrollTextCtrl(wx.TextCtrl):
         """Increase or decrease value while scrolling."""
         
         # set new value
-        self._setNewValue(evt.GetWheelRotation(), evt.AltDown())
+        self._setNewValue(evt.GetWheelRotation()*SCROLL_DIRECTION, evt.AltDown())
     # ----
     
     
