@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -235,6 +235,7 @@ class panelDocuments(wx.Panel):
             menu.Append(ID_documentAnnotationEdit, "Edit Annotation...")
             menu.AppendSeparator()
             menu.Append(ID_documentAnnotationSendToMassCalculator, "Show Isotopic Pattern...")
+            menu.Append(ID_documentAnnotationSendToMassToFormula, "Send to Mass to Formula...")
             menu.Append(ID_documentAnnotationSendToEnvelopeFit, "Send to Envelope Fit...")
             menu.AppendSeparator()
             menu.Append(ID_documentAnnotationsCalibrateBy, "Calibrate by Annotations...")
@@ -294,6 +295,7 @@ class panelDocuments(wx.Panel):
         
         self.Bind(wx.EVT_MENU, self.onNotationEdit, id=ID_documentAnnotationEdit)
         self.Bind(wx.EVT_MENU, self.onSendToMassCalculator, id=ID_documentAnnotationSendToMassCalculator)
+        self.Bind(wx.EVT_MENU, self.onSendToMassToFormula, id=ID_documentAnnotationSendToMassToFormula)
         self.Bind(wx.EVT_MENU, self.onSendToEnvelopeFit, id=ID_documentAnnotationSendToEnvelopeFit)
         self.Bind(wx.EVT_MENU, self.parent.onDocumentAnnotationsCalibrateBy, id=ID_documentAnnotationsCalibrateBy)
         self.Bind(wx.EVT_MENU, self.onNotationDelete, id=ID_documentAnnotationDelete)
@@ -516,9 +518,9 @@ class panelDocuments(wx.Panel):
             dlg.Destroy()
             
             if itemType == 'annotation':
-                self.parent.onDocumentChanged(('annotations'))
+                self.parent.onDocumentChanged(items=('annotations'))
             elif itemType == 'match':
-                self.parent.onDocumentChanged(('matches'))
+                self.parent.onDocumentChanged(items=('matches'))
         
         else:
             dlg.Destroy()
@@ -565,6 +567,22 @@ class panelDocuments(wx.Panel):
     # ----
     
     
+    def onSendToMassToFormula(self, evt=None):
+        """Send selected item to Mass To Formula panel."""
+        
+        # get selected item
+        item = self.documentTree.GetSelection()
+        itemType = self.documentTree.getItemType(item)
+        itemData = self.documentTree.GetPyData(item)
+        
+        # send data to Mass To Formula panel
+        if itemData.radical:
+            self.parent.onToolsMassToFormula(mass=itemData.mz, charge=itemData.charge, agentFormula='e')
+        else:
+            self.parent.onToolsMassToFormula(mass=itemData.mz, charge=itemData.charge, agentFormula='H')
+    # ----
+    
+    
     def onSendToEnvelopeFit(self, evt=None):
         """Send selected item to envelope fit panel."""
         
@@ -583,7 +601,7 @@ class panelDocuments(wx.Panel):
         elif itemType == 'match':
             
             scale = None
-            if itemData.sequenceRange and config.envfit['loss'] == 'H' and config.envfit['gain'] == 'H{2}':
+            if itemData.sequenceRange and config.envelopeFit['loss'] == 'H' and config.envelopeFit['gain'] == 'H{2}':
                 scale = [0, itemData.sequenceRange[1]-itemData.sequenceRange[0]]
             
             self.parent.onToolsEnvelopeFit(formula=itemData.formula, charge=itemData.charge, scale=scale)
@@ -607,6 +625,7 @@ class panelDocuments(wx.Panel):
         docItem = self.documentTree.getItemByData(docData)
         
         # select document
+        self.documentTree.highlightDocument(docItem)
         self.documentTree.SelectItem(docItem)
     # ----
     
@@ -1019,7 +1038,7 @@ class documentsTree(wx.TreeCtrl):
         
         # check siblings
         child = self.GetNextSibling(root)
-        if child:
+        if child and child.IsOk():
             if self.GetPyData(child) is data:
                 return child
             matchedItem = self.getItemByData(data, child, cookie)
@@ -1083,7 +1102,7 @@ class documentsTree(wx.TreeCtrl):
         # set document bullet
         if itemType == 'document':
             if enable:
-                self.SetItemImage(item, self.GetPyData(item).bullet, wx.TreeItemIcon_Normal)
+                self.SetItemImage(item, self.GetPyData(item).bulletIndex, wx.TreeItemIcon_Normal)
             else:
                 self.SetItemImage(item, 1, wx.TreeItemIcon_Normal)
         
@@ -1114,7 +1133,8 @@ class documentsTree(wx.TreeCtrl):
         """Append document to tree."""
         
         # add bullet
-        docData.bullet = self.bullets.Add(self._makeColourBullet(docData.colour, True))
+        bullet = self._makeColourBullet(docData.colour, True)
+        docData.bulletIndex = self.bullets.Add(bullet)
         
         # get title
         title = docData.title
@@ -1123,7 +1143,7 @@ class documentsTree(wx.TreeCtrl):
         
         # add document
         docItem = self.AppendItem(self.GetRootItem(), title)
-        self.SetItemImage(docItem, docData.bullet, wx.TreeItemIcon_Normal)
+        self.SetItemImage(docItem, docData.bulletIndex, wx.TreeItemIcon_Normal)
         self.SetPyData(docItem, docData)
         
         # add annotations
@@ -1219,10 +1239,12 @@ class documentsTree(wx.TreeCtrl):
         # add bullet
         item = self.getParentItem(item, 1)
         docData = self.GetPyData(item)
-        docData.bullet = self.bullets.Add(self._makeColourBullet(docData.colour, True))
+        
+        bullet = self._makeColourBullet(docData.colour, True)
+        docData.bulletIndex = self.bullets.Add(bullet)
         
         # set new bullet
-        self.SetItemImage(item, docData.bullet, wx.TreeItemIcon_Normal)
+        self.SetItemImage(item, docData.bulletIndex, wx.TreeItemIcon_Normal)
     # ----
     
     
@@ -1270,21 +1292,21 @@ class documentsTree(wx.TreeCtrl):
         return bitmap
     # ----
     
-
+    
 
 
 class fileDropTarget(wx.FileDropTarget):
     """Generic drop target for files."""
     
-    def __init__(self, fce):
+    def __init__(self, fn):
         wx.FileDropTarget.__init__(self)
-        self.fce = fce
+        self.fn = fn
     # ----
     
     
     def OnDropFiles(self, x, y, paths):
         """Open dropped files."""
-        self.fce(paths=paths)
+        self.fn(paths=paths)
     # ----
     
 
