@@ -45,9 +45,10 @@ class panelMassCalculator(wx.MiniFrame):
         self.currentCompound = None
         self.currentIons = None
         self.currentIon = None
-        self.currentPatternScan = None
+        self.currentPattern = None
         self.currentPatternProfile = None
         self.currentPatternPeaks = None
+        self.currentPatternScan = None
         
         # make gui items
         self.makeGUI()
@@ -247,9 +248,17 @@ class panelMassCalculator(wx.MiniFrame):
         self.patternCollapse_butt = wx.BitmapButton(ctrlPanel, ID_massCalculatorCollapse, images.lib['arrowsDown'], size=(mwx.TOOLBAR_TOOLSIZE), style=wx.BORDER_NONE)
         self.patternCollapse_butt.Bind(wx.EVT_BUTTON, self.onCollapse)
         
+        patternPeakShape_label = wx.StaticText(ctrlPanel, -1, "Shape:")
+        patternPeakShape_label.SetFont(wx.SMALL_FONT)
+        self.patternPeakShape_choice = wx.Choice(ctrlPanel, -1, choices=['Symmetrical', 'Asymmetrical'], size=(125, mwx.CHOICE_HEIGHT))
+        self.patternPeakShape_choice.Select(0)
+        if config.massCalculator['patternPeakShape'] == 'gausslorentzian':
+            self.patternPeakShape_choice.Select(1)
+        self.patternPeakShape_choice.Bind(wx.EVT_CHOICE, self.onProfileChanged)
+        
         patternFwhm_label = wx.StaticText(ctrlPanel, -1, "FWHM:")
         patternFwhm_label.SetFont(wx.SMALL_FONT)
-        self.patternFwhm_value = mwx.scrollTextCtrl(ctrlPanel, -1, str(config.massCalculator['patternFwhm']), multiplier=0.1, limits=(0.001,10), digits=3, size=(60, mwx.SMALL_TEXTCTRL_HEIGHT))
+        self.patternFwhm_value = mwx.scrollTextCtrl(ctrlPanel, -1, str(config.massCalculator['patternFwhm']), multiplier=0.1, limits=(0.001,10), digits=4, size=(60, mwx.SMALL_TEXTCTRL_HEIGHT))
         self.patternFwhm_value.SetFont(wx.SMALL_FONT)
         self.patternFwhm_value.Bind(wx.EVT_TEXT, self.onPatternChanged)
         
@@ -257,30 +266,33 @@ class panelMassCalculator(wx.MiniFrame):
         patternIntensity_label.SetFont(wx.SMALL_FONT)
         self.patternIntensity_value = mwx.scrollTextCtrl(ctrlPanel, -1, str(config.massCalculator['patternIntensity']), multiplier=0.1, limits=(1,None), size=(60, mwx.SMALL_TEXTCTRL_HEIGHT))
         self.patternIntensity_value.SetFont(wx.SMALL_FONT)
-        self.patternIntensity_value.Bind(wx.EVT_TEXT, self.onPatternChanged)
+        self.patternIntensity_value.Bind(wx.EVT_TEXT, self.onProfileChanged)
         
         patternBaseline_label = wx.StaticText(ctrlPanel, -1, "Baseline:")
         patternBaseline_label.SetFont(wx.SMALL_FONT)
         self.patternBaseline_value = mwx.scrollTextCtrl(ctrlPanel, -1, str(config.massCalculator['patternBaseline']), multiplier=0.1, limits=(0,None), size=(60, mwx.SMALL_TEXTCTRL_HEIGHT))
         self.patternBaseline_value.SetFont(wx.SMALL_FONT)
-        self.patternBaseline_value.Bind(wx.EVT_TEXT, self.onPatternChanged)
+        self.patternBaseline_value.Bind(wx.EVT_TEXT, self.onProfileChanged)
         
         patternShift_label = wx.StaticText(ctrlPanel, -1, "Shift:")
         patternShift_label.SetFont(wx.SMALL_FONT)
         self.patternShift_value = mwx.scrollTextCtrl(ctrlPanel, -1, "0", step=0.001, digits=3, limits=(-1.,1.), size=(60, mwx.SMALL_TEXTCTRL_HEIGHT))
         self.patternShift_value.SetFont(wx.SMALL_FONT)
-        self.patternShift_value.Bind(wx.EVT_TEXT, self.onPatternChanged)
+        self.patternShift_value.Bind(wx.EVT_TEXT, self.onProfileChanged)
         
-        self.showPeaks_check = wx.CheckBox(ctrlPanel, -1, "Show peaks")
+        self.showPeaks_check = wx.CheckBox(ctrlPanel, -1, "Peaks")
         self.showPeaks_check.SetFont(wx.SMALL_FONT)
         self.showPeaks_check.SetValue(config.massCalculator['patternShowPeaks'])
-        self.showPeaks_check.Bind(wx.EVT_CHECKBOX, self.onPatternChanged)
+        self.showPeaks_check.Bind(wx.EVT_CHECKBOX, self.onProfileChanged)
         
         # pack controls
         controls = wx.BoxSizer(wx.HORIZONTAL)
         controls.AddSpacer(mwx.CONTROLBAR_RSPACE)
         controls.Add(self.patternCollapse_butt, 0, wx.ALIGN_CENTER_VERTICAL)
         controls.AddSpacer(10)
+        controls.Add(patternPeakShape_label, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
+        controls.Add(self.patternPeakShape_choice, 0, wx.ALIGN_CENTER_VERTICAL)
+        controls.AddSpacer(20)
         controls.Add(patternFwhm_label, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
         controls.Add(self.patternFwhm_value, 0, wx.ALIGN_CENTER_VERTICAL)
         controls.AddSpacer(20)
@@ -337,7 +349,7 @@ class panelMassCalculator(wx.MiniFrame):
         """Make plot canvas and set defalt parameters."""
         
         # init canvas
-        self.patternCanvas = mspy.plot.canvas(self, size=(550, 270), style=mwx.PLOTCANVAS_STYLE_PANEL)
+        self.patternCanvas = mspy.plot.canvas(self, size=(550, 300), style=mwx.PLOTCANVAS_STYLE_PANEL)
         self.patternCanvas.draw(mspy.plot.container([]))
         
         # set default params
@@ -461,12 +473,14 @@ class panelMassCalculator(wx.MiniFrame):
             self.currentCompound = None
             self.currentIons = None
             self.currentIon = None
-            self.currentPatternScan = None
+            self.currentPattern = None
             self.currentPatternProfile = None
             self.currentPatternPeaks = None
+            self.currentPatternScan = None
             self.updateSummary()
             self.updateIonsList()
             self.updatePatternCanvas()
+            self.updateTmpSpectrum()
             return
         
         # calculate ion series
@@ -479,6 +493,7 @@ class panelMassCalculator(wx.MiniFrame):
         self.updateSummary()
         self.updateIonsList()
         self.updatePatternCanvas()
+        self.updateTmpSpectrum()
     # ----
     
     
@@ -487,10 +502,12 @@ class panelMassCalculator(wx.MiniFrame):
         
         # get all params
         if not self.getParams():
-            self.currentPatternScan = None
+            self.currentPattern = None
             self.currentPatternProfile = None
             self.currentPatternPeaks = None
+            self.currentPatternScan = None
             self.updatePatternCanvas()
+            self.updateTmpSpectrum()
             return
         
         # calculate pattern
@@ -503,6 +520,32 @@ class panelMassCalculator(wx.MiniFrame):
         
         # update gui
         self.updatePatternCanvas(rescale=rescale)
+        self.updateTmpSpectrum()
+    # ----
+    
+    
+    def onProfileChanged(self, evt=None):
+        """Shift tmp profile."""
+        
+        # check pattern
+        if self.currentPattern == None:
+            return
+        
+        # get all params
+        if not self.getParams():
+            self.currentPatternProfile = None
+            self.currentPatternPeaks = None
+            self.currentPatternScan = None
+            self.updatePatternCanvas()
+            self.updateTmpSpectrum()
+            return
+        
+        # re-calculate pattern profile
+        self.makeProfile()
+        
+        # update gui
+        self.updatePatternCanvas(rescale=False)
+        self.updateTmpSpectrum()
     # ----
     
     
@@ -583,9 +626,10 @@ class panelMassCalculator(wx.MiniFrame):
         self.currentCompound = None
         self.currentIons = None
         self.currentIon = None
-        self.currentPatternScan = None
+        self.currentPattern = None
         self.currentPatternProfile = None
         self.currentPatternPeaks = None
+        self.currentPatternScan = None
         
         # check
         if not formula:
@@ -634,6 +678,7 @@ class panelMassCalculator(wx.MiniFrame):
             self.updateSummary()
             self.updateIonsList()
             self.updatePatternCanvas()
+            self.updateTmpSpectrum()
             return
         
         # calculate ion series
@@ -654,6 +699,7 @@ class panelMassCalculator(wx.MiniFrame):
         if not done:
             self.runPattern()
             self.updatePatternCanvas()
+            self.updateTmpSpectrum()
     # ----
     
     
@@ -686,6 +732,10 @@ class panelMassCalculator(wx.MiniFrame):
             patternBaseline = float(self.patternBaseline_value.GetValue())
             patternShift = float(self.patternShift_value.GetValue())
             config.massCalculator['patternShowPeaks'] = self.showPeaks_check.GetValue()
+            
+            config.massCalculator['patternPeakShape'] = 'gaussian'
+            if self.patternPeakShape_choice.GetStringSelection() == 'Asymmetrical':
+                config.massCalculator['patternPeakShape'] = 'gausslorentzian'
         
         except:
             wx.Bell()
@@ -715,7 +765,6 @@ class panelMassCalculator(wx.MiniFrame):
         
         # check pattern values
         if patternFwhm < 0.001 \
-            or patternFwhm > 10 \
             or patternIntensity < 1 \
             or patternBaseline >= patternIntensity:
             wx.Bell()
@@ -794,11 +843,16 @@ class panelMassCalculator(wx.MiniFrame):
         container = mspy.plot.container([])
         
         # check data
-        if self.currentPatternScan == None or self.currentPatternProfile == None or self.currentPatternPeaks == None:
+        if self.currentPatternScan == None:
             self.patternCanvas.draw(container)
-            self.parent.updateTmpSpectrum(None)
             return
         
+        # get number of relevant digits
+        fwhm = config.massCalculator['patternFwhm']
+        digits = int(abs(numpy.floor(numpy.log10(fwhm))))
+        if fwhm > 1: digits = 1
+        elif round(fwhm, digits-1) == 0: digits += 1
+        
         # get selected charge
         legend = '[M]'
         if self.currentIon != None:
@@ -813,7 +867,7 @@ class panelMassCalculator(wx.MiniFrame):
             showPoints = False,
             showLabels = True,
             showTicks = True,
-            labelDigits = config.main['mzDigits'],
+            labelDigits = digits,
             labelBgr = True,
             labelAngle = 90,
             labelFont = labelFont
@@ -821,14 +875,15 @@ class panelMassCalculator(wx.MiniFrame):
         container.append(spectrum)
         
         # add individual peaks to container
-        for peak in self.currentPatternPeaks:
-            spectrum = mspy.plot.points(peak,
-                lineColour = (50,140,0),
-                showLines = True,
-                showPoints = False,
-                exactFit = True
-            )
-            container.append(spectrum)
+        if self.currentPatternPeaks != None:
+            for peak in self.currentPatternPeaks:
+                spectrum = mspy.plot.points(peak,
+                    lineColour = (50,140,0),
+                    showLines = True,
+                    showPoints = False,
+                    exactFit = True
+                )
+                container.append(spectrum)
         
         # get current axis
         if not rescale:
@@ -843,12 +898,22 @@ class panelMassCalculator(wx.MiniFrame):
         
         # draw spectra
         self.patternCanvas.draw(container, xAxis=xAxis, yAxis=yAxis)
+    # ----
+    
+    
+    def updateTmpSpectrum(self):
+        """Show current profile in the main canvas."""
         
-        # draw profile as tmp spectrum
-        tmpSpectrum = None
-        if self.currentIon != None:
-            tmpSpectrum = self.currentPatternProfile + numpy.array([config.massCalculator['patternShift'], 0.0])
-        self.parent.updateTmpSpectrum(tmpSpectrum)
+        # check data
+        if self.currentPatternProfile == None:
+            self.parent.updateTmpSpectrum(None)
+            return
+        
+        # apply current shift
+        profile = mspy.offset(self.currentPatternProfile, x=config.massCalculator['patternShift'])
+        
+        # draw tmp spectrum
+        self.parent.updateTmpSpectrum(profile)
     # ----
     
     
@@ -907,11 +972,12 @@ class panelMassCalculator(wx.MiniFrame):
     
     
     def runPattern(self):
-        """Generate isotopic pattern spectrum."""
+        """Calculate isotopic pattern."""
         
-        self.currentPatternScan = None
+        self.currentPattern = None
         self.currentPatternProfile = None
         self.currentPatternPeaks = None
+        self.currentPatternScan = None
         
         # run task
         try:
@@ -921,53 +987,115 @@ class panelMassCalculator(wx.MiniFrame):
             if self.currentIon != None:
                 charge = self.currentIon[3]
             
-            # calculate compound pattern
-            pattern = self.currentCompound.pattern(
+            # calculate pattern
+            self.currentPattern = self.currentCompound.pattern(
                 fwhm = min(0.9, config.massCalculator['patternFwhm']),
                 threshold = config.massCalculator['patternThreshold'],
                 charge = charge,
                 agentFormula = config.massCalculator['ionseriesAgent'],
-                agentCharge = config.massCalculator['ionseriesAgentCharge']
+                agentCharge = config.massCalculator['ionseriesAgentCharge'],
+                real = False
             )
             
-            # make peaklist from pattern
-            peaklist = []
-            for isotope in pattern:
-                ai = isotope[1]*(config.massCalculator['patternIntensity'] - config.massCalculator['patternBaseline']) + config.massCalculator['patternBaseline']
-                peak = mspy.peak(
-                    mz = isotope[0],
-                    ai = ai,
-                    base = config.massCalculator['patternBaseline'],
-                    fwhm = config.massCalculator['patternFwhm'],
-                    charge = charge
-                )
-                peaklist.append(peak)
-            peaklist = mspy.peaklist(peaklist)
-            
-            # make individual peak shapes
-            self.currentPatternPeaks = []
-            if config.massCalculator['patternShowPeaks']:
-                for isotope in peaklist:
-                    peak = mspy.gaussian(
-                        x = isotope.mz,
-                        minY = isotope.base,
-                        maxY = isotope.ai,
-                        fwhm = isotope.fwhm
-                    )
-                    self.currentPatternPeaks.append(peak)
-            
-            # make profile spectrum
-            self.currentPatternProfile = mspy.profile(peaklist)
-            
-            # make final spectrum
-            self.currentPatternScan = mspy.scan(profile=self.currentPatternProfile, peaklist=peaklist)
+            # make profile
+            self.makeProfile()
             
         # task canceled
         except mspy.ForceQuit:
-            self.currentPatternScan = None
+            self.currentPattern = None
             self.currentPatternProfile = None
             self.currentPatternPeaks = None
+            self.currentPatternScan = None
     # ----
     
     
-
+    def makeProfile(self):
+        """Generate pattern profile."""
+        
+        self.currentPatternProfile = None
+        self.currentPatternPeaks = None
+        self.currentPatternScan = None
+        
+        # check pattern
+        if self.currentPattern == None:
+            return
+        
+        # get selected charge
+        charge = 0
+        if self.currentIon != None:
+            charge = self.currentIon[3]
+        
+        # make profile
+        self.currentPatternProfile = mspy.profile(
+            peaklist = self.currentPattern,
+            fwhm = config.massCalculator['patternFwhm'],
+            points = 20,
+            model = config.massCalculator['patternPeakShape'],
+        )
+        
+        # get scale and shift for specified intensity and baseline
+        basepeak = mspy.basepeak(self.currentPatternProfile)
+        scale = (config.massCalculator['patternIntensity'] - config.massCalculator['patternBaseline']) / self.currentPatternProfile[basepeak][1]
+        shift = config.massCalculator['patternBaseline']
+        
+        # rescale profile
+        self.currentPatternProfile = mspy.multiply(self.currentPatternProfile, y=scale)
+        self.currentPatternProfile = mspy.offset(self.currentPatternProfile, y=shift)
+        
+        # make real peaklist from profile
+        peaklist = []
+        for isotope in mspy.maxima(self.currentPatternProfile):
+            mz = isotope[0]
+            centroid = mspy.centroid(self.currentPatternProfile, isotope[0], isotope[1]*0.99)
+            if abs(mz-centroid) < config.massCalculator['patternFwhm']/20:
+                mz = centroid
+            peak = mspy.peak(
+                mz = mz,
+                ai = isotope[1],
+                base = shift,
+                charge = charge
+            )
+            peaklist.append(peak)
+        peaklist = mspy.peaklist(peaklist)
+        
+        # make individual peak shapes
+        self.currentPatternPeaks = []
+        if config.massCalculator['patternShowPeaks']:
+            
+            # gaussian shape
+            if config.massCalculator['patternPeakShape'] == 'gaussian':
+                for isotope in self.currentPattern:
+                    peak = mspy.gaussian(
+                        x = isotope[0],
+                        minY = shift,
+                        maxY = isotope[1]*scale+shift,
+                        fwhm = config.massCalculator['patternFwhm']
+                    )
+                    self.currentPatternPeaks.append(peak)
+            
+            # lorentzian shape
+            elif config.massCalculator['patternPeakShape'] == 'lorentzian':
+                for isotope in self.currentPattern:
+                    peak = mspy.lorentzian(
+                        x = isotope[0],
+                        minY = shift,
+                        maxY = isotope[1]*scale+shift,
+                        fwhm = config.massCalculator['patternFwhm']
+                    )
+                    self.currentPatternPeaks.append(peak)
+            
+            # gauss-lorentzian shape
+            elif config.massCalculator['patternPeakShape'] == 'gausslorentzian':
+                for isotope in self.currentPattern:
+                    peak = mspy.gausslorentzian(
+                        x = isotope[0],
+                        minY = shift,
+                        maxY = isotope[1]*scale+shift,
+                        fwhm = config.massCalculator['patternFwhm']
+                    )
+                    self.currentPatternPeaks.append(peak)
+        
+        # make scan object
+        self.currentPatternScan = mspy.scan(profile=self.currentPatternProfile, peaklist=peaklist)
+    # ----
+    
