@@ -21,6 +21,7 @@ import wx
 import webbrowser
 import tempfile
 import os.path
+import numpy
 
 # load modules
 from ids import *
@@ -43,7 +44,9 @@ class panelMassToFormula(wx.MiniFrame):
         
         self.processing = None
         
+        self.currentDocument = None
         self.currentFormulae = None
+        self.currentMass = None
         
         # make gui items
         self.makeGUI()
@@ -219,6 +222,10 @@ class panelMassToFormula(wx.MiniFrame):
         self.ruleRDBEInt_check.SetValue(('RDBEInt' in config.massToFormula['rules']))
         self.ruleRDBEInt_check.Bind(wx.EVT_CHECKBOX, self.onApplyRules)
         
+        self.checkPattern_check = wx.CheckBox(panel, -1, "Check isotopic pattern")
+        self.checkPattern_check.SetFont(wx.SMALL_FONT)
+        self.checkPattern_check.SetValue(config.massToFormula['checkPattern'])
+        
         # pack controls
         sizer = wx.BoxSizer(wx.HORIZONTAL)
         sizer.AddSpacer(mwx.CONTROLBAR_LSPACE)
@@ -227,7 +234,8 @@ class panelMassToFormula(wx.MiniFrame):
         sizer.Add(self.ruleNOPSC_check, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
         sizer.Add(self.ruleNOPS_check, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
         sizer.Add(self.ruleRDBE_check, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
-        sizer.Add(self.ruleRDBEInt_check, 0, wx.ALIGN_CENTER_VERTICAL)
+        sizer.Add(self.ruleRDBEInt_check, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 40)
+        sizer.Add(self.checkPattern_check, 0, wx.ALIGN_CENTER_VERTICAL)
         sizer.AddSpacer(mwx.CONTROLBAR_RSPACE)
         
         mainSizer = wx.BoxSizer(wx.VERTICAL)
@@ -264,9 +272,10 @@ class panelMassToFormula(wx.MiniFrame):
         self.formulaeList.InsertColumn(3, "error", wx.LIST_FORMAT_RIGHT)
         self.formulaeList.InsertColumn(4, "H/C", wx.LIST_FORMAT_RIGHT)
         self.formulaeList.InsertColumn(5, "rdbe", wx.LIST_FORMAT_RIGHT)
+        self.formulaeList.InsertColumn(6, "pattern", wx.LIST_FORMAT_RIGHT)
         
         # set column widths
-        for col, width in enumerate((240,130,120,80,80,80)):
+        for col, width in enumerate((200,110,100,80,80,80,80)):
             self.formulaeList.SetColumnWidth(col, width)
     # ----
     
@@ -564,7 +573,7 @@ class panelMassToFormula(wx.MiniFrame):
         # recalculate errors
         if self.currentFormulae:
             for x, item in enumerate(self.currentFormulae):
-                self.currentFormulae[x][3] = mspy.delta(config.massToFormula['mass'], item[2], config.massToFormula['units'])
+                self.currentFormulae[x][3] = mspy.delta(self.currentMass, item[2], config.massToFormula['units'])
         
         # update GUI
         self.updateFormulaeList()
@@ -582,15 +591,23 @@ class panelMassToFormula(wx.MiniFrame):
     # ----
     
     
-    def setData(self, mass=None, charge=None, tolerance=None, units=None, agentFormula=None):
+    def setData(self, document=None, mass=None, charge=None, tolerance=None, units=None, agentFormula=None):
         """Set data."""
         
-        # clear previous data
-        self.currentFormulae = None
+        # set new document
+        self.currentDocument = document
         
-        # check values
+        # enable/disable profile check
+        self.checkPattern_check.Enable(True)
+        if self.currentDocument == None or not self.currentDocument.spectrum.hasprofile():
+            self.checkPattern_check.Enable(False)
+        
+        # check mass
         if not mass:
-            mass = ''
+            return
+        
+        # clear previous results
+        self.currentFormulae = None
         
         # update values
         self.mass_value.ChangeValue(str(mass))
@@ -619,11 +636,12 @@ class panelMassToFormula(wx.MiniFrame):
         
         # try to get values
         try:
-            config.massToFormula['mass'] = float(self.mass_value.GetValue())
+            self.currentMass = float(self.mass_value.GetValue())
             config.massToFormula['charge'] = int(self.charge_value.GetValue())
             config.massToFormula['tolerance'] = float(self.tolerance_value.GetValue())
             config.massToFormula['formulaMin'] = self.formulaMin_value.GetValue()
             config.massToFormula['formulaMax'] = self.formulaMax_value.GetValue()
+            config.massToFormula['checkPattern'] = self.checkPattern_check.GetValue()
             
             config.massToFormula['units'] = 'ppm'
             if self.unitsDa_radio.GetValue():
@@ -679,7 +697,7 @@ class panelMassToFormula(wx.MiniFrame):
             
             # approximate CHNO composition from neutral mass
             mass = mspy.mz(
-                mass = config.massToFormula['mass'],
+                mass = self.currentMass,
                 charge = 0,
                 currentCharge = config.massToFormula['charge'],
                 agentFormula = config.massToFormula['ionization'],
@@ -714,7 +732,7 @@ class panelMassToFormula(wx.MiniFrame):
             
             # calculate formulae
             formulae = mspy.formulator(
-                mz = config.massToFormula['mass'],
+                mz = self.currentMass,
                 charge = config.massToFormula['charge'],
                 tolerance = config.massToFormula['tolerance'],
                 units = config.massToFormula['units'],
@@ -728,20 +746,30 @@ class panelMassToFormula(wx.MiniFrame):
             buff = []
             for formula in formulae:
                 
+                # make compound
                 cmpd = mspy.compound(formula)
                 mass = cmpd.mass(0)
                 mz = cmpd.mz(config.massToFormula['charge'], config.massToFormula['ionization'], 1)[0]
-                error = mspy.delta(config.massToFormula['mass'], mz, config.massToFormula['units'])
+                error = mspy.delta(self.currentMass, mz, config.massToFormula['units'])
+                errorDa = mspy.delta(self.currentMass, mz, 'Da')
                 
+                # compare isotopic pattern
+                similarity = None
+                if config.massToFormula['checkPattern']:
+                    similarity = self.compareIsotopicPattern(cmpd, config.massToFormula['charge'], config.massToFormula['ionization'], errorDa)
+                
+                # count ratios
                 countC = float(cmpd.count('C', groupIsotopes=True))
                 countH = float(cmpd.count('H', groupIsotopes=True))
                 hc = None
                 if countC:
                     hc = countH/countC
                 
+                # count rdbe
                 rdbe = cmpd.rdbe()
                 
-                buff.append([cmpd.formula(), mass, mz, error, hc, rdbe, cmpd])
+                # add item
+                buff.append([cmpd.formula(), mass, mz, error, hc, rdbe, similarity, cmpd])
             
             self.currentFormulae = buff
         
@@ -773,7 +801,7 @@ class panelMassToFormula(wx.MiniFrame):
         for index, item in enumerate(self.currentFormulae):
             
             # apply rules
-            if not self.applyRules(item[6]):
+            if not self.applyRules(item[7]):
                 continue
             
             # format data
@@ -786,6 +814,10 @@ class panelMassToFormula(wx.MiniFrame):
             if item[4] != None:
                 hc = '%.1f' % item[4]
             
+            similarity = 'n/a'
+            if item[6] != None:
+                similarity = '%.1f' % item[6]
+            
             # add data
             row += 1
             self.formulaeList.InsertStringItem(row, item[0])
@@ -794,6 +826,7 @@ class panelMassToFormula(wx.MiniFrame):
             self.formulaeList.SetStringItem(row, 3, error)
             self.formulaeList.SetStringItem(row, 4, hc)
             self.formulaeList.SetStringItem(row, 5, rdbe)
+            self.formulaeList.SetStringItem(row, 6, similarity)
             self.formulaeList.SetItemData(row, index)
         
         # sort data
@@ -805,6 +838,66 @@ class panelMassToFormula(wx.MiniFrame):
     # ----
     
     
+    def compareIsotopicPattern(self, compound, charge, ionization, shift=0.0):
+        """Compare theoretical and real isotopic pattern."""
+        
+        # check document
+        if self.currentDocument == None or not self.currentDocument.spectrum.hasprofile():
+            return None
+        
+        # get baseline window
+        baselineWindow = 1.
+        if config.processing['peakpicking']['baseline']:
+            baselineWindow = 1./config.processing['baseline']['precision']
+        
+        # get baseline
+        baseline = self.currentDocument.spectrum.baseline(
+            window = baselineWindow,
+            offset = config.processing['baseline']['offset']
+        )
+        
+        # approximate fwhm
+        fwhm = 0.1
+        mz = compound.mz(charge, ionization, 1)[0]
+        peak = mspy.labelpeak(
+            signal = self.currentDocument.spectrum.profile,
+            mz = mz+shift,
+            pickingHeight = config.processing['peakpicking']['pickingHeight'],
+            baseline = baseline
+        )
+        if peak:
+            fwhm = peak.fwhm
+        
+        # make pattern
+        pattern = compound.pattern(
+            fwhm = fwhm,
+            threshold = 0.01,
+            charge = charge,
+            agentFormula = ionization,
+            agentCharge = 1,
+            real = True
+        )
+        
+        # add error shift to pattern
+        for x in range(len(pattern)):
+            pattern[x][0] += shift
+        
+        # match pattern to signal
+        rms = mspy.matchpattern(
+            signal = self.currentDocument.spectrum.profile,
+            pattern = pattern,
+            pickingHeight = config.processing['peakpicking']['pickingHeight'],
+            baseline = baseline,
+        )
+        
+        # calc similarity
+        if rms != None:
+            rms = (1-rms)*100
+        
+        return rms
+    # ----
+    
+    
     def applyRules(self, compound):
         """Apply current rules."""
         
