@@ -187,22 +187,27 @@ class panelMatch(wx.MiniFrame):
         self.filterAnnotations_check = wx.CheckBox(panel, -1, "Annotated")
         self.filterAnnotations_check.SetFont(wx.SMALL_FONT)
         self.filterAnnotations_check.SetValue(config.match['filterAnnotations'])
+        self.filterAnnotations_check.Bind(wx.EVT_CHECKBOX, self.onFilter)
         
         self.filterMatches_check = wx.CheckBox(panel, -1, "Matched")
         self.filterMatches_check.SetFont(wx.SMALL_FONT)
         self.filterMatches_check.SetValue(config.match['filterMatches'])
+        self.filterMatches_check.Bind(wx.EVT_CHECKBOX, self.onFilter)
         
         self.filterUnselected_check = wx.CheckBox(panel, -1, "Unselected")
         self.filterUnselected_check.SetFont(wx.SMALL_FONT)
         self.filterUnselected_check.SetValue(config.match['filterUnselected'])
+        self.filterUnselected_check.Bind(wx.EVT_CHECKBOX, self.onFilter)
         
         self.filterIsotopes_check = wx.CheckBox(panel, -1, "Isotopes")
         self.filterIsotopes_check.SetFont(wx.SMALL_FONT)
         self.filterIsotopes_check.SetValue(config.match['filterIsotopes'])
+        self.filterIsotopes_check.Bind(wx.EVT_CHECKBOX, self.onFilter)
         
         self.filterUnknown_check = wx.CheckBox(panel, -1, "Unknown")
         self.filterUnknown_check.SetFont(wx.SMALL_FONT)
         self.filterUnknown_check.SetValue(config.match['filterUnknown'])
+        self.filterUnknown_check.Bind(wx.EVT_CHECKBOX, self.onFilter)
         
         # pack elements
         sizer = wx.BoxSizer(wx.HORIZONTAL)
@@ -384,6 +389,45 @@ class panelMatch(wx.MiniFrame):
     # ----
     
     
+    def onFilter(self, evt):
+        """Apply peaklist filter."""
+        
+        # get current filters
+        config.match['filterAnnotations'] = 0
+        if self.filterAnnotations_check.GetValue():
+            config.match['filterAnnotations'] = 1
+        
+        config.match['filterMatches'] = 0
+        if self.filterMatches_check.GetValue():
+            config.match['filterMatches'] = 1
+        
+        config.match['filterUnselected'] = 0
+        if self.filterUnselected_check.GetValue():
+            config.match['filterUnselected'] = 1
+        
+        config.match['filterIsotopes'] = 0
+        if self.filterIsotopes_check.GetValue():
+            config.match['filterIsotopes'] = 1
+        
+        config.match['filterUnknown'] = 0
+        if self.filterUnknown_check.GetValue():
+            config.match['filterUnknown'] = 1
+        
+        # clear values
+        self.currentPeaklist = None
+        self.currentSummary = None
+        self.currentErrors = []
+        self.currentCalibrationPoints = []
+        
+        # get peaklist
+        self.getPeaklist()
+        
+        # update gui
+        self.updateErrorCanvas()
+        self.updateMatchSummary()
+    # ----
+    
+    
     def onMatch(self, evt=None):
         """Match data to peaklist."""
         
@@ -480,10 +524,14 @@ class panelMatch(wx.MiniFrame):
         # update values
         self.currentData = matchData
         self.currentSummaryData = summaryData
+        self.currentPeaklist = None
         self.currentSummary = None
         self.currentErrors = []
         self.currentCalibrationPoints = []
         
+        # get current peaklist
+        self.getPeaklist()
+        
         # clear error canvas and summary
         self.updateErrorCanvas()
         self.updateMatchSummary()
@@ -640,6 +688,7 @@ class panelMatch(wx.MiniFrame):
         """Clear all."""
         
         self.currentData = None
+        self.currentSummaryData = None
         self.currentPeaklist = None
         self.currentSummary = None
         self.currentErrors = []
