@@ -16,6 +16,7 @@
 # -------------------------------------------------------------------------
 
 # load libs
+import threading
 import wx
 import wx.grid
 
@@ -33,17 +34,19 @@ class panelPeakDifferences(wx.MiniFrame):
     """Peak differences tool."""
     
     def __init__(self, parent):
-        wx.MiniFrame.__init__(self, parent, -1, 'Peak Differences', size=(400, 300), style=wx.DEFAULT_FRAME_STYLE)
+        wx.MiniFrame.__init__(self, parent, -1, 'Peak Differences', size=(500, 400), style=wx.DEFAULT_FRAME_STYLE)
         
         self.parent = parent
         
+        self.processing = None
+        
         self.currentDocument = None
+        self.currentDifference = None
         self.currentDifferences = None
         self.currentMatches = None
-        self.currentLimit = None
         
-        self.difference = None
-        self.dipeptides = None
+        # init amino acids and dipeptides
+        self.initAminoacids()
         
         # make gui items
         self.makeGUI()
@@ -57,13 +60,18 @@ class panelPeakDifferences(wx.MiniFrame):
         # make toolbar
         toolbar = self.makeToolbar()
         
-        # make panel
+        # make panels
         mainPanel = self.makeMainPanel()
+        gauge = self.makeGaugePanel()
         
         # pack element
         self.mainSizer = wx.BoxSizer(wx.VERTICAL)
         self.mainSizer.Add(toolbar, 0, wx.EXPAND, 0)
         self.mainSizer.Add(mainPanel, 1, wx.EXPAND, 0)
+        self.mainSizer.Add(gauge, 0, wx.EXPAND, 0)
+        
+        # hide gauge
+        self.mainSizer.Hide(2)
         
         # fit layout
         self.mainSizer.Fit(self)
@@ -112,9 +120,9 @@ class panelPeakDifferences(wx.MiniFrame):
         toleranceUnits_label = wx.StaticText(panel, -1, "m/z")
         toleranceUnits_label.SetFont(wx.SMALL_FONT)
         
-        self.showAll_check = wx.CheckBox(panel, -1, "Show full table")
-        self.showAll_check.SetFont(wx.SMALL_FONT)
-        self.showAll_check.SetValue(config.peakDifferences['showAll'])
+        self.consolidate_check = wx.CheckBox(panel, -1, "Hide umatched")
+        self.consolidate_check.SetFont(wx.SMALL_FONT)
+        self.consolidate_check.SetValue(config.peakDifferences['consolidate'])
         
         self.search_butt = wx.Button(panel, -1, "Search", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
         self.search_butt.Bind(wx.EVT_BUTTON, self.onSearch)
@@ -136,7 +144,7 @@ class panelPeakDifferences(wx.MiniFrame):
         sizer.Add(self.tolerance_value, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
         sizer.Add(toleranceUnits_label, 0, wx.ALIGN_CENTER_VERTICAL)
         sizer.AddSpacer(20)
-        sizer.Add(self.showAll_check, 0, wx.ALIGN_CENTER_VERTICAL)
+        sizer.Add(self.consolidate_check, 0, wx.ALIGN_CENTER_VERTICAL)
         sizer.AddStretchSpacer()
         sizer.AddSpacer(20)
         sizer.Add(self.search_butt, 0, wx.ALIGN_CENTER_VERTICAL)
@@ -177,7 +185,7 @@ class panelPeakDifferences(wx.MiniFrame):
         """Make differences grid."""
         
         # make table
-        self.differencesGrid = wx.grid.Grid(panel, -1, size=(625, 400), style=mwx.GRID_STYLE)
+        self.differencesGrid = wx.grid.Grid(panel, -1, size=(700, 500), style=mwx.GRID_STYLE)
         self.differencesGrid.CreateGrid(0, 0)
         self.differencesGrid.DisableDragColSize()
         self.differencesGrid.DisableDragRowSize()
@@ -212,42 +220,79 @@ class panelPeakDifferences(wx.MiniFrame):
     # ----
     
     
+    def makeGaugePanel(self):
+        """Make processing gauge."""
+        
+        panel = wx.Panel(self, -1)
+        
+        # make elements
+        self.gauge = mwx.gauge(panel, -1)
+        
+        stop_butt = wx.BitmapButton(panel, -1, images.lib['stopper'], style=wx.BORDER_NONE)
+        stop_butt.Bind(wx.EVT_BUTTON, self.onStop)
+        
+        # pack elements
+        sizer = wx.BoxSizer(wx.HORIZONTAL)
+        sizer.Add(self.gauge, 1, wx.ALIGN_CENTER_VERTICAL)
+        sizer.AddSpacer(10)
+        sizer.Add(stop_butt, 0, wx.ALIGN_CENTER_VERTICAL)
+        
+        # fit layout
+        mainSizer = wx.BoxSizer(wx.VERTICAL)
+        if wx.Platform == '__WXMAC__':
+            mainSizer.Add(wx.StaticLine(panel), 0, wx.EXPAND|wx.TOP, -1)
+        mainSizer.Add(sizer, 1, wx.EXPAND|wx.ALL, mwx.GAUGE_SPACE)
+        panel.SetSizer(mainSizer)
+        mainSizer.Fit(panel)
+        
+        return panel
+    # ----
+    
+    
     def onClose(self, evt):
-        """Destroy this frame."""
+        """Hide this frame."""
+        
+        # check processing
+        if self.processing != None:
+            wx.Bell()
+            return
+        
+        # close self
         self.Destroy()
     # ----
     
     
-    def onSearch(self, evt):
-        """Generate differences and search for specified mass(es)."""
+    def onProcessing(self, status=True):
+        """Show processing gauge."""
         
-        self.currentMatches = None
+        self.gauge.SetValue(0)
         
-        # check document
-        if not self.currentDocument:
+        if status:
+            self.MakeModal(True)
+            self.mainSizer.Show(2)
+        else:
+            self.MakeModal(False)
+            self.mainSizer.Hide(2)
+            self.processing = None
+            mspy.start()
+        
+        # fit layout
+        self.differencesGrid.SetMinSize(self.differencesGrid.GetSize())
+        self.Layout()
+        self.mainSizer.Fit(self)
+        try: wx.Yield()
+        except: pass
+        self.differencesGrid.SetMinSize((-1,-1))
+    # ----
+    
+    
+    def onStop(self, evt):
+        """Cancel current processing."""
+        
+        if self.processing and self.processing.isAlive():
+            mspy.stop()
+        else:
             wx.Bell()
-            return
-        
-        # get params
-        if not self.getParams():
-            wx.Bell()
-            self.updateDifferencesGrid()
-            self.updateMatchesGrid()
-            return
-        
-        # calculate differences
-        if not self.calcDifferences():
-            wx.Bell()
-            self.updateDifferencesGrid()
-            self.updateMatchesGrid()
-            return
-        
-        # search
-        self.searchAll()
-        
-        # update gui
-        self.updateDifferencesGrid()
-        self.updateMatchesGrid()
     # ----
     
     
@@ -263,16 +308,10 @@ class panelPeakDifferences(wx.MiniFrame):
         # highlight selected cell
         self.differencesGrid.SelectBlock(row, col, row, col)
         
-        # get peaklist
-        peaklist = self.currentDocument.spectrum.peaklist
-        if not peaklist:
-            wx.Bell()
-            return
-        
         # get peaks and diff
-        mz1 = peaklist[col].mz
-        mz2 = peaklist[row].mz
-        diff = abs(mz1-mz2)
+        mz1 = self.currentDifferences[col][0][0]
+        mz2 = self.currentDifferences[row][0][0]
+        diff = abs(mz1 - mz2)
         
         # highlight masses in plot
         self.parent.updateMassPoints([mz1,mz2])
@@ -295,16 +334,10 @@ class panelPeakDifferences(wx.MiniFrame):
         # highlight selected cell
         self.differencesGrid.SelectBlock(row, col, row, col)
         
-        # get peaklist
-        peaklist = self.currentDocument.spectrum.peaklist
-        if not peaklist:
-            wx.Bell()
-            return
-        
         # get peaks and diff
-        mz1 = peaklist[col].mz
-        mz2 = peaklist[row].mz
-        diff = abs(mz1-mz2)
+        mz1 = self.currentDifferences[col][0][0]
+        mz2 = self.currentDifferences[row][0][0]
+        diff = abs(mz1 - mz2)
         
         # highlight masses in plot
         self.parent.updateMassPoints([mz1,mz2])
@@ -320,6 +353,51 @@ class panelPeakDifferences(wx.MiniFrame):
     # ----
     
     
+    def onSearch(self, evt):
+        """Generate differences and search for specified mass(es)."""
+        
+        # check processing
+        if self.processing:
+            return
+        
+        # clear previous
+        self.currentDifferences = None
+        self.currentMatches = None
+        
+        # check document
+        if not self.currentDocument:
+            wx.Bell()
+            return
+        
+        # get params
+        if not self.getParams():
+            wx.Bell()
+            self.updateDifferencesGrid()
+            self.updateMatchesGrid()
+            return
+        
+        # show processing gauge
+        self.onProcessing(True)
+        self.search_butt.Enable(False)
+        
+        # do processing
+        self.processing = threading.Thread(target=self.runSearch)
+        self.processing.start()
+        
+        # pulse gauge while working
+        while self.processing and self.processing.isAlive():
+            self.gauge.pulse()
+        
+        # update gui
+        self.updateDifferencesGrid()
+        self.updateMatchesGrid()
+        
+        # hide processing gauge
+        self.onProcessing(False)
+        self.search_butt.Enable(True)
+    # ----
+    
+    
     def setData(self, document):
         """Set data."""
         
@@ -327,7 +405,6 @@ class panelPeakDifferences(wx.MiniFrame):
         self.currentDocument = document
         self.currentDifferences = None
         self.currentMatches = None
-        self.currentLimit = None
         
         # update gui
         self.updateDifferencesGrid()
@@ -342,15 +419,15 @@ class panelPeakDifferences(wx.MiniFrame):
         try:
             
             if self.difference_value.GetValue():
-                self.difference = float(self.difference_value.GetValue())
+                self.currentDifference = float(self.difference_value.GetValue())
             else:
-                self.difference = None
+                self.currentDifference = None
             
             config.peakDifferences['aminoacids'] = int(self.aminoacids_check.GetValue())
             config.peakDifferences['dipeptides'] = int(self.dipeptides_check.GetValue())
             config.peakDifferences['tolerance'] = float(self.tolerance_value.GetValue())
             config.peakDifferences['massType'] = int(self.massTypeAv_radio.GetValue())
-            config.peakDifferences['showAll'] = int(self.showAll_check.GetValue())
+            config.peakDifferences['consolidate'] = int(self.consolidate_check.GetValue())
             
             return True
             
@@ -372,50 +449,47 @@ class panelPeakDifferences(wx.MiniFrame):
         if not self.currentDifferences:
             return
         
-        # get peaklist
-        peaklist = self.currentDocument.spectrum.peaklist
-        peaks = len(peaklist)
+        # get grid size
+        size = len(self.currentDifferences)
         
         # create new cells
-        self.differencesGrid.AppendCols(peaks)
-        self.differencesGrid.AppendRows(peaks)
+        self.differencesGrid.AppendCols(size)
+        self.differencesGrid.AppendRows(size)
         
         # create labels
         mzFormat = '%0.' + `config.main['mzDigits']` + 'f'
         cellAttr = wx.grid.GridCellAttr()
         cellAttr.SetReadOnly(True)
-        for x in range(peaks):
-            mass = mzFormat % peaklist[x].mz
-            self.differencesGrid.SetColLabelValue(x, mass)
-            self.differencesGrid.SetRowLabelValue(x, mass)
+        for x in range(size):
+            label = mzFormat % self.currentDifferences[x][0][0]
+            self.differencesGrid.SetColLabelValue(x, label)
+            self.differencesGrid.SetRowLabelValue(x, label)
             self.differencesGrid.SetColAttr(x, cellAttr)
         
         # paste data
         mzFormat = '%0.' + `config.main['mzDigits']` + 'f'
-        for x in range(peaks):
-            for y in range(peaks):
+        for x in range(size):
+            for y in range(size):
                 
                 # get difference indexes
-                if y==x:
+                if y == x:
                     self.differencesGrid.SetCellValue(x, y, '---')
                     continue
-                elif y<x:
-                    i=x
-                    j=y
-                elif y>x:
-                    i=y
-                    j=x
-                
-                # check limit
-                if not config.peakDifferences['showAll'] and self.currentDifferences[i][j][0] > self.currentLimit:
-                    continue
+                elif y < x:
+                    i = x
+                    j = (y + 1)
+                elif y > x:
+                    i = y
+                    j = (x + 1)
                 
                 # set value
                 diff = mzFormat % self.currentDifferences[i][j][0]
                 self.differencesGrid.SetCellValue(x, y, diff)
                 
                 # highlight matches
-                if self.currentDifferences[i][j][1] == 'value':
+                if self.currentDifferences[i][j][1] == False:
+                    continue
+                elif self.currentDifferences[i][j][1] == 'value':
                     self.differencesGrid.SetCellBackgroundColour(x, y, (100,255,100))
                 elif self.currentDifferences[i][j][1] == 'amino':
                     self.differencesGrid.SetCellBackgroundColour(x, y, (0,200,255))
@@ -466,134 +540,126 @@ class panelPeakDifferences(wx.MiniFrame):
     # ----
     
     
-    def searchAll(self):
-        """Search differences for specified value, aminoacids or dipeptides."""
-        
-        # get amino acids
-        aminoacids = []
-        for abbr in mspy.monomers:
-            if mspy.monomers[abbr].category == '_InternalAA':
-                aminoacids.append(abbr)
-        
-        # get maxima
-        aaMin = 0
-        aaMax = 0
-        dipMin = 0
-        dipMax = 0
-        if config.peakDifferences['aminoacids'] or config.peakDifferences['dipeptides']:
-            masses = []
-            for aa in aminoacids:
-                masses.append(mspy.monomers[aa].mass[config.peakDifferences['massType']])
-            aaMin = min(masses) - config.peakDifferences['tolerance']
-            aaMax = max(masses) + config.peakDifferences['tolerance']
-            dipMin = min(masses)*2 - config.peakDifferences['tolerance']
-            dipMax = max(masses)*2 + config.peakDifferences['tolerance']
-        
-        # get current max
-        if self.difference:
-            self.currentLimit = max(aaMin, aaMax, dipMin, dipMax, self.difference+config.peakDifferences['tolerance'])
-        else:
-            self.currentLimit = max(aaMin, aaMax, dipMin, dipMax)
-        
-        # calculate dipeptides
-        if not self.dipeptides and config.peakDifferences['dipeptides']:
-            self.calcDipeptides()
-        
-        # search
-        for x in range(len(self.currentDifferences)):
-            for y in range(len(self.currentDifferences[x])):
-                
-                diff = self.currentDifferences[x][y][0]
-                diffMin = diff - config.peakDifferences['tolerance']
-                diffMax = diff + config.peakDifferences['tolerance']
-                
-                self.currentDifferences[x][y][1] = False
-                matched = False
-                
-                # search for value
-                if self.difference and diffMin <= self.difference <= diffMax:
-                    self.currentDifferences[x][y][1] = 'value'
-                    matched = True
-                
-                # search for aminoacids
-                if not matched and config.peakDifferences['aminoacids'] and aaMin <= diff <= aaMax:
-                    for aa in aminoacids:
-                        if diffMin <= mspy.monomers[aa].mass[config.peakDifferences['massType']] <= diffMax:
-                            self.currentDifferences[x][y][1] = 'amino'
-                            matched = True
-                
-                # search for dipeptides
-                if not matched and config.peakDifferences['dipeptides'] and dipMin <= diff <= dipMax:
-                    for dip in self.dipeptides:
-                        if diffMin <= self.dipeptides[dip][config.peakDifferences['massType']] <= diffMax:
-                            self.currentDifferences[x][y][1] = 'dipep'
-                            break
-    # ----
-    
-    
     def searchSelected(self, diff):
         """Search difference for specified value, aminoacids or dipeptides."""
         
         self.currentMatches = []
         
-        # get amino acids
-        aminoacids = []
-        for abbr in mspy.monomers:
-            if mspy.monomers[abbr].category == '_InternalAA':
-                aminoacids.append(abbr)
-        
         # search for value
-        if self.difference:
-            error = diff - self.difference
+        if self.currentDifference:
+            error = diff - self.currentDifference
             if abs(error) <= config.peakDifferences['tolerance']:
-                self.currentMatches.append([str(self.difference), error])
+                self.currentMatches.append([str(self.currentDifference), error])
         
         # search for aminoacids
         if config.peakDifferences['aminoacids']:
-            for aa in aminoacids:
-                error = diff - mspy.monomers[aa].mass[config.peakDifferences['massType']]
+            for aa in self._aaMasses:
+                error = diff - self._aaMasses[aa][config.peakDifferences['massType']]
                 if abs(error) <= config.peakDifferences['tolerance']:
                     self.currentMatches.append([aa, error])
         
         # search for dipeptides
         if config.peakDifferences['dipeptides']:
-            for dip in self.dipeptides:
-                error = diff - self.dipeptides[dip][config.peakDifferences['massType']]
+            for dip in self._dipMasses:
+                error = diff - self._dipMasses[dip][config.peakDifferences['massType']]
                 if abs(error) <= config.peakDifferences['tolerance']:
                     self.currentMatches.append([dip, error])
     # ----
     
     
-    def calcDifferences(self):
-        """Calculate differences for current peaklist."""
+    def runSearch(self):
+        """Calculate differences for current peaklist and search for matches."""
         
-        # get peaklist
-        peaklist = self.currentDocument.spectrum.peaklist
-        if not peaklist:
-            return False
+        # run task
+        try:
+            
+            # get peaklist
+            peaklist = self.currentDocument.spectrum.peaklist
+            if not peaklist:
+                return False
+            
+            # init limits
+            diffMin = 0.0
+            diffMax = 0.0
+            if self.currentDifference:
+                diffMin = self.currentDifference - config.peakDifferences['tolerance']
+                diffMax = self.currentDifference + config.peakDifferences['tolerance']
+            aaMin = self._aaLimits[0] - config.peakDifferences['tolerance']
+            aaMax = self._aaLimits[1] + config.peakDifferences['tolerance']
+            dipMin = self._dipLimits[0] - config.peakDifferences['tolerance']
+            dipMax = self._dipLimits[1] + config.peakDifferences['tolerance']
+            
+            # calc differences
+            self.currentDifferences = []
+            for x in range(len(peaklist)):
+                rowBuff = [(peaklist[x].mz, x)]
+                for y in range(x+1):
+                    
+                    mspy.CHECK_FORCE_QUIT()
+                    
+                    diff = peaklist[x].mz - peaklist[y].mz
+                    match = False
+                    
+                    # match specified value
+                    if self.currentDifference != None and (diffMin <= diff <= diffMax):
+                        match = 'value'
+                    
+                    # match amino acids
+                    if not match and config.peakDifferences['aminoacids'] and (aaMin <= diff <= aaMax):
+                        for aa in self._aaMasses:
+                            error = diff - self._aaMasses[aa][config.peakDifferences['massType']]
+                            if abs(error) <= config.peakDifferences['tolerance']:
+                                match = 'amino'
+                                break
+                    
+                    # match dipeptides
+                    if not match and config.peakDifferences['dipeptides'] and (dipMin <= diff <= dipMax):
+                        for dip in self._dipMasses:
+                            error = diff - self._dipMasses[dip][config.peakDifferences['massType']]
+                            if abs(error) <= config.peakDifferences['tolerance']:
+                                match = 'dipep'
+                                break
+                    
+                    # append difference
+                    rowBuff.append((diff, match))
+                
+                # append row
+                self.currentDifferences.append(rowBuff)
+            
+            # consolidate table - remove unmatched peaks
+            if config.peakDifferences['consolidate']:
+                self.consolidateTable()
         
-        # calc differences
-        self.currentDifferences = []
-        for x in range(len(peaklist)):
-            buff = []
-            for y in range(x+1):
-                buff.append([peaklist[x].mz-peaklist[y].mz, False])
-            self.currentDifferences.append(buff)
-        
-        return True
+        # task canceled
+        except mspy.ForceQuit:
+            self.currentDifferences = []
+            return
     # ----
     
     
-    def calcDipeptides(self):
-        """Calculate dipeptides masses."""
+    def initAminoacids(self):
+        """Calculate amino acids / dipeptides masses and ranges."""
+        
+        self._aaLimits = [0.0, 1000.0]
+        self._dipLimits = [0.0, 1000.0]
+        self._aaMasses = {}
+        self._dipMasses = {}
         
         # get amino acids
         aminoacids = []
         for abbr in mspy.monomers:
             if mspy.monomers[abbr].category == '_InternalAA':
                 aminoacids.append(abbr)
+                self._aaMasses[abbr] = mspy.monomers[abbr].mass
         
-        self.dipeptides = {}
+        # approximate mass limits
+        masses = []
+        for aa in aminoacids:
+            masses.append(mspy.monomers[aa].mass[1])
+        self._aaLimits = [min(masses)-1, max(masses)+1]
+        self._dipLimits = [2*self._aaLimits[0]-1, 2*self._aaLimits[1]+1]
+        
+        # generate dipeptides
         for x in range(len(aminoacids)):
             for y in range(x, len(aminoacids)):
                 
@@ -609,7 +675,37 @@ class panelPeakDifferences(wx.MiniFrame):
                 else:
                     label = aX+aY
                 
-                self.dipeptides[label] = mass
+                self._dipMasses[label] = mass
+    # ----
+    
+    
+    def consolidateTable(self):
+        """Remove unmatched peaks."""
+        
+        # find matches
+        indexes = []
+        for i, row in enumerate(self.currentDifferences):
+            for j, item in enumerate(row[1:]):
+                if item[1] != False: 
+                    if not i in indexes:
+                        indexes.append(i)
+                    if not j in indexes:
+                        indexes.append(j)
+        
+        # sort indexes
+        indexes.sort()
+        
+        # consolidate table
+        buff = []
+        for i in indexes[:]:
+            row = self.currentDifferences[i]
+            rowBuff = [row[0]]
+            for j, item in enumerate(row[1:]):
+                if j in indexes:
+                    rowBuff.append(item)
+            buff.append(rowBuff)
+            
+        self.currentDifferences = buff
     # ----
     
 
