@@ -198,7 +198,7 @@ class panelProcessing(wx.MiniFrame):
         self.mathOperationCombineAll_radio = wx.RadioButton(panel, -1, "Sum all visible")
         self.mathOperationOverlayAll_radio = wx.RadioButton(panel, -1, "Overlay all visible")
         
-        self.mathOperationNorm_radio = wx.RadioButton(panel, -1, "Normalize")
+        self.mathOperationNorm_radio = wx.RadioButton(panel, -1, "Normalize A")
         self.mathOperationCombine_radio = wx.RadioButton(panel, -1, "Combine A + B")
         self.mathOperationSubtract_radio = wx.RadioButton(panel, -1, "Subtract A - B")
         self.mathOperationOverlay_radio = wx.RadioButton(panel, -1, "Overlay max(A, B)")
@@ -218,28 +218,35 @@ class panelProcessing(wx.MiniFrame):
         self.mathOperationOverlay_radio.Bind(wx.EVT_RADIOBUTTON, self.onMathChanged)
         self.mathOperationMultiply_radio.Bind(wx.EVT_RADIOBUTTON, self.onMathChanged)
         
+        mathSpectrumA_label = wx.StaticText(panel, -1, "Spectrum A:")
+        self.mathSpectrumA_choice = wx.Choice(panel, -1, choices=[], size=(200, mwx.CHOICE_HEIGHT))
+        self.mathSpectrumA_choice.Disable()
+        
         mathSpectrumB_label = wx.StaticText(panel, -1, "Spectrum B:")
         self.mathSpectrumB_choice = wx.Choice(panel, -1, choices=[], size=(200, mwx.CHOICE_HEIGHT))
         self.mathSpectrumB_choice.Disable()
         
         # pack elements
         grid = wx.GridBagSizer(mwx.GRIDBAG_VSPACE, mwx.GRIDBAG_HSPACE)
+        grid.SetEmptyCellSize((-1,0))
         
         grid.Add(mathOperationMulti_label, (0,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
         grid.Add(self.mathOperationAverageAll_radio, (0,1), (1,2))
         grid.Add(self.mathOperationCombineAll_radio, (1,1), (1,2))
         grid.Add(self.mathOperationOverlayAll_radio, (2,1), (1,2))
         
-        grid.Add(mathOperationSingle_label, (3,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        grid.Add(self.mathOperationNorm_radio, (3,1), (1,2))
-        grid.Add(self.mathOperationCombine_radio, (4,1), (1,2))
-        grid.Add(self.mathOperationSubtract_radio, (5,1), (1,2))
-        grid.Add(self.mathOperationOverlay_radio, (6,1), (1,2))
-        grid.Add(self.mathOperationMultiply_radio, (7,1), flag=wx.ALIGN_CENTER_VERTICAL)
-        grid.Add(self.mathMultiply_value, (7,2), flag=wx.EXPAND)
+        grid.Add(mathOperationSingle_label, (4,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
+        grid.Add(self.mathOperationNorm_radio, (4,1), (1,2))
+        grid.Add(self.mathOperationCombine_radio, (5,1), (1,2))
+        grid.Add(self.mathOperationSubtract_radio, (6,1), (1,2))
+        grid.Add(self.mathOperationOverlay_radio, (7,1), (1,2))
+        grid.Add(self.mathOperationMultiply_radio, (8,1), flag=wx.ALIGN_CENTER_VERTICAL)
+        grid.Add(self.mathMultiply_value, (8,2), flag=wx.EXPAND)
         
-        grid.Add(mathSpectrumB_label, (8,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        grid.Add(self.mathSpectrumB_choice, (8,1), (1,2))
+        grid.Add(mathSpectrumA_label, (10,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
+        grid.Add(self.mathSpectrumA_choice, (10,1), (1,2))
+        grid.Add(mathSpectrumB_label, (11,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
+        grid.Add(self.mathSpectrumB_choice, (11,1), (1,2))
         
         mainSizer = wx.BoxSizer(wx.VERTICAL)
         mainSizer.Add(grid, 0, wx.ALIGN_CENTER|wx.ALL, mwx.PANEL_SPACE_MAIN)
@@ -1230,6 +1237,7 @@ class panelProcessing(wx.MiniFrame):
         
         # set document
         self.currentDocument = document
+        self.updateCurrentDocument()
         
         # clear preview
         self.clearPreview()
@@ -1361,6 +1369,28 @@ class panelProcessing(wx.MiniFrame):
     # ----
     
     
+    def updateCurrentDocument(self):
+        """Show selected document title as Spectrum A."""
+        
+        # clear choice
+        self.mathSpectrumA_choice.Clear()
+        
+        # check document
+        if self.currentDocument == None:
+            self.mathSpectrumA_choice.Append('None')
+            self.mathSpectrumA_choice.Select(0)
+            return
+        
+        # show selected document
+        for x, document in enumerate(self.parent.documents):
+            if document is self.currentDocument:
+                title = '#%d: %s' % (x+1, document.title)
+                self.mathSpectrumA_choice.Append(title)
+                self.mathSpectrumA_choice.Select(0)
+                return
+    # ----
+    
+    
     def updateAvailableDocuments(self):
         """Update list of documents in math and batch panels."""
         
@@ -1424,15 +1454,16 @@ class panelProcessing(wx.MiniFrame):
             # process spectrum
             if config.processing['math']['operation'] == 'normalize':
                 self.previewData = mspy.normalize(self.previewData)
+                self.previewData = mspy.multiply(self.previewData, y=100)
             
             elif config.processing['math']['operation'] == 'combine':
-                self.previewData = mspy.combine(spectrumA, self.previewData)
+                self.previewData = mspy.combine(self.previewData, spectrumB)
             
             elif config.processing['math']['operation'] == 'overlay':
-                self.previewData = mspy.overlay(spectrumA, self.previewData)
+                self.previewData = mspy.overlay(self.previewData, spectrumB)
             
             elif config.processing['math']['operation'] == 'subtract':
-                self.previewData = mspy.subtract(spectrumA, self.previewData)
+                self.previewData = mspy.subtract(self.previewData, spectrumB)
             
             elif config.processing['math']['operation'] == 'multiply':
                 self.previewData = mspy.multiply(self.previewData, y=config.processing['math']['multiplier'])
