@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -99,7 +99,6 @@ class panelProfound(wx.MiniFrame):
         self.query_butt.Bind(wx.EVT_BUTTON, self.onToolSelected)
         
         self.search_butt = wx.Button(panel, -1, "Search", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
-        self.search_butt.SetFont(wx.SMALL_FONT)
         self.search_butt.Bind(wx.EVT_BUTTON, self.onSearch)
         
         # pack elements
@@ -133,17 +132,17 @@ class panelProfound(wx.MiniFrame):
         
         # make sequence elements
         paramTaxonomy_label = wx.StaticText(panel, -1, "Taxonomy:")
-        self.paramTaxonomy_combo = wx.ComboBox(panel, -1, choices=[], size=(300, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
+        self.paramTaxonomy_choice = wx.Choice(panel, -1, choices=[], size=(300, mwx.CHOICE_HEIGHT))
         
         paramDatabase_label = wx.StaticText(panel, -1, "Database:")
-        self.paramDatabase_combo = wx.ComboBox(panel, -1, choices=[], size=(150, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
+        self.paramDatabase_choice = wx.Choice(panel, -1, choices=[], size=(150, mwx.CHOICE_HEIGHT))
         
         paramEnzyme_label = wx.StaticText(panel, -1, " Enzyme:")
-        self.paramEnzyme_combo = wx.ComboBox(panel, -1, choices=[], size=(130, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
+        self.paramEnzyme_choice = wx.Choice(panel, -1, choices=[], size=(130, mwx.CHOICE_HEIGHT))
         
         paramMiscleavages_label = wx.StaticText(panel, -1, " Miscl.:")
-        self.paramMiscleavages_combo = wx.ComboBox(panel, -1, choices=['0','1','2','3','4'], size=(50, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.paramMiscleavages_combo.SetValue(str(config.profound['miscleavages']))
+        self.paramMiscleavages_choice = wx.Choice(panel, -1, choices=['0','1','2','3','4'], size=(50, mwx.CHOICE_HEIGHT))
+        self.paramMiscleavages_choice.SetStringSelection(str(config.profound['miscleavages']))
         
         # make modifications elements
         self.paramFixedMods_label = wx.StaticText(panel, -1, "Complete modifications:")
@@ -170,16 +169,16 @@ class panelProfound(wx.MiniFrame):
         
         paramPeptideTol_label = wx.StaticText(panel, -1, "Peptide tolerance:")
         self.paramPeptideTol_value = wx.TextCtrl(panel, -1, str(config.profound['peptideTol']), size=(50, -1), validator=mwx.validator('floatPos'))
-        self.paramPeptideTolUnits_combo = wx.ComboBox(panel, -1, choices=['Da','%','ppm'], size=(80, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.paramPeptideTolUnits_combo.SetValue(config.profound['peptideTolUnits'])
+        self.paramPeptideTolUnits_choice = wx.Choice(panel, -1, choices=['Da','%','ppm'], size=(80, mwx.CHOICE_HEIGHT))
+        self.paramPeptideTolUnits_choice.SetStringSelection(config.profound['peptideTolUnits'])
         
         paramMassType_label = wx.StaticText(panel, -1, "Mass type:")
-        self.paramMassType_combo = wx.ComboBox(panel, -1, choices=['Monoisotopic', 'Average'], size=(150, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.paramMassType_combo.SetValue(config.profound['massType'])
+        self.paramMassType_choice = wx.Choice(panel, -1, choices=['Monoisotopic', 'Average'], size=(150, mwx.CHOICE_HEIGHT))
+        self.paramMassType_choice.SetStringSelection(config.profound['massType'])
         
         paramCharge_label = wx.StaticText(panel, -1, "Charge:")
-        self.paramCharge_combo = wx.ComboBox(panel, -1, choices=['MH+','M'], size=(150, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.paramCharge_combo.SetValue(config.profound['charge'])
+        self.paramCharge_choice = wx.Choice(panel, -1, choices=['MH+','M'], size=(150, mwx.CHOICE_HEIGHT))
+        self.paramCharge_choice.SetStringSelection(config.profound['charge'])
         
         # results elements
         self.paramExpectation_radio = wx.RadioButton(panel, -1, "Expectation value:", style=wx.RB_GROUP)
@@ -200,13 +199,13 @@ class panelProfound(wx.MiniFrame):
         
         sequenceGrid = wx.GridBagSizer(mwx.GRIDBAG_VSPACE, mwx.GRIDBAG_HSPACE)
         sequenceGrid.Add(paramTaxonomy_label, (0,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        sequenceGrid.Add(self.paramTaxonomy_combo, (0,1), (1,5), flag=wx.EXPAND)
+        sequenceGrid.Add(self.paramTaxonomy_choice, (0,1), (1,5), flag=wx.EXPAND)
         sequenceGrid.Add(paramDatabase_label, (1,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        sequenceGrid.Add(self.paramDatabase_combo, (1,1), flag=wx.EXPAND)
+        sequenceGrid.Add(self.paramDatabase_choice, (1,1), flag=wx.EXPAND)
         sequenceGrid.Add(paramEnzyme_label, (1,2), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        sequenceGrid.Add(self.paramEnzyme_combo, (1,3), flag=wx.EXPAND)
+        sequenceGrid.Add(self.paramEnzyme_choice, (1,3), flag=wx.EXPAND)
         sequenceGrid.Add(paramMiscleavages_label, (1,4), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        sequenceGrid.Add(self.paramMiscleavages_combo, (1,5))
+        sequenceGrid.Add(self.paramMiscleavages_choice, (1,5))
         sequenceGrid.AddGrowableCol(1)
         sequenceGrid.AddGrowableCol(3)
         
@@ -230,11 +229,11 @@ class panelProfound(wx.MiniFrame):
         massesGrid.Add(self.paramProteinPIHigh_value, (1,3), flag=wx.ALIGN_CENTER_VERTICAL)
         massesGrid.Add(paramPeptideTol_label, (2,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
         massesGrid.Add(self.paramPeptideTol_value, (2,1), flag=wx.ALIGN_CENTER_VERTICAL)
-        massesGrid.Add(self.paramPeptideTolUnits_combo, (2,3), (1,2), flag=wx.ALIGN_CENTER_VERTICAL)
+        massesGrid.Add(self.paramPeptideTolUnits_choice, (2,3), (1,2), flag=wx.ALIGN_CENTER_VERTICAL)
         massesGrid.Add(paramMassType_label, (0,5), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        massesGrid.Add(self.paramMassType_combo, (0,6), flag=wx.ALIGN_CENTER_VERTICAL)
+        massesGrid.Add(self.paramMassType_choice, (0,6), flag=wx.ALIGN_CENTER_VERTICAL)
         massesGrid.Add(paramCharge_label, (1,5), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        massesGrid.Add(self.paramCharge_combo, (1,6), flag=wx.ALIGN_CENTER_VERTICAL)
+        massesGrid.Add(self.paramCharge_choice, (1,6), flag=wx.ALIGN_CENTER_VERTICAL)
         massesGrid.AddGrowableCol(4)
         
         resultsGrid = wx.GridBagSizer(mwx.GRIDBAG_VSPACE, mwx.GRIDBAG_HSPACE)
@@ -481,18 +480,18 @@ class panelProfound(wx.MiniFrame):
         try:
             
             config.profound['title'] = self.paramTitle_value.GetValue()
-            config.profound['database'] = self.paramDatabase_combo.GetValue()
-            config.profound['taxonomy'] = self.paramTaxonomy_combo.GetValue()
-            config.profound['enzyme'] = self.paramEnzyme_combo.GetValue()
-            config.profound['miscleavages'] = self.paramMiscleavages_combo.GetValue()
+            config.profound['database'] = self.paramDatabase_choice.GetStringSelection()
+            config.profound['taxonomy'] = self.paramTaxonomy_choice.GetStringSelection()
+            config.profound['enzyme'] = self.paramEnzyme_choice.GetStringSelection()
+            config.profound['miscleavages'] = self.paramMiscleavages_choice.GetStringSelection()
             config.profound['proteinMassLow'] = self.paramProteinMassLow_value.GetValue()
             config.profound['proteinMassHigh'] = self.paramProteinMassHigh_value.GetValue()
             config.profound['proteinPILow'] = self.paramProteinPILow_value.GetValue()
             config.profound['proteinPIHigh'] = self.paramProteinPIHigh_value.GetValue()
             config.profound['peptideTol'] = self.paramPeptideTol_value.GetValue()
-            config.profound['peptideTolUnits'] = self.paramPeptideTolUnits_combo.GetValue()
-            config.profound['massType'] = self.paramMassType_combo.GetValue()
-            config.profound['charge'] = self.paramCharge_combo.GetValue()
+            config.profound['peptideTolUnits'] = self.paramPeptideTolUnits_choice.GetStringSelection()
+            config.profound['massType'] = self.paramMassType_choice.GetStringSelection()
+            config.profound['charge'] = self.paramCharge_choice.GetStringSelection()
             config.profound['expectation'] = self.paramExpectation_value.GetValue()
             config.profound['candidates'] = self.paramCandidates_value.GetValue()
             
@@ -703,27 +702,27 @@ class panelProfound(wx.MiniFrame):
         }
         
         # update databases
-        self.paramDatabase_combo.Clear()
+        self.paramDatabase_choice.Clear()
         names = sorted(self.currentParams['DBSE'].keys())
         for item in names:
-            self.paramDatabase_combo.Append(item)
+            self.paramDatabase_choice.Append(item)
         if config.profound['database'] in names:
-            self.paramDatabase_combo.Select(names.index(config.profound['database']))
+            self.paramDatabase_choice.Select(names.index(config.profound['database']))
         
         # update taxonomy
-        self.paramTaxonomy_combo.Clear()
+        self.paramTaxonomy_choice.Clear()
         for item in self.currentParams['SPEC']:
-            self.paramTaxonomy_combo.Append(item)
+            self.paramTaxonomy_choice.Append(item)
         if config.profound['taxonomy'] in self.currentParams['SPEC']:
-            self.paramTaxonomy_combo.Select(self.currentParams['SPEC'].index(config.profound['taxonomy']))
+            self.paramTaxonomy_choice.Select(self.currentParams['SPEC'].index(config.profound['taxonomy']))
         
         # update enzymes
-        self.paramEnzyme_combo.Clear()
+        self.paramEnzyme_choice.Clear()
         names = sorted(self.currentParams['ENZ'].keys())
         for item in names:
-            self.paramEnzyme_combo.Append(item)
+            self.paramEnzyme_choice.Append(item)
         if config.profound['enzyme'] in names:
-            self.paramEnzyme_combo.Select(names.index(config.profound['enzyme']))
+            self.paramEnzyme_choice.Select(names.index(config.profound['enzyme']))
         
         # update fixed modifications
         self.paramFixedMods_listbox.Clear()
@@ -756,21 +755,31 @@ class panelProfound(wx.MiniFrame):
         buff += '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">\n'
         buff += '<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">\n'
         buff += '<head>\n'
-        buff += '  <title>ProFound Search</title>\n'
-        buff += '   <style type="text/css">\n'
-        buff += '     <!--\n'
-        buff += '       body{text-align: center; margin: auto; font-size: .8em; font-family: Arial, Verdana, Geneva, Helvetica, sans-serif;}\n'
-        buff += '       #data{display:none;}\n'
-        buff += '       #info{width: 350px; margin: auto; margin-top: 5em; background-color: #f2f2f2; border: 1px solid #aaa;}\n'
-        buff += '       #info p.sending{font-weight: bold;}\n'
-        buff += '       #info p.note{font-size: .85em;}\n'
-        buff += '       #info p.button{padding: .5em 1em;}\n'
-        buff += '       h1{font-size: 1.3em; color: #fff; background-color: #aaa; margin: 0; padding: .2em;}\n'
-        buff += '     -->\n'
-        buff += '   </style>\n'
+        buff += '  <title>mMass - ProFound Search</title>\n'
+        buff += '  <style type="text/css">\n'
+        buff += '    <!--\n'
+        buff += '      body{margin: auto; font-size: .8em; font-family: Arial, Verdana, Geneva, Helvetica, sans-serif; text-align: center; text-shadow: 1px 1px 1px #fff; color: #000; background-color: #f5f4f2;}\n'
+        buff += '      h1{margin: 0; padding: .7em; font-size: 1.4em; font-weight: bold; text-align: center; color: #999; border-bottom: 1px solid #ddd; }\n'
+        buff += '      #data{display:none;}\n'
+        buff += '      #info{ width: 350px; margin: auto; margin-top: 5em; background-color: #edece9; border-radius: 7px; border: 2px solid #fff; box-shadow: 0 0 5px rgba(0,0,0,.5);}\n'
+        buff += '      #sending{font-weight: bold}\n'
+        buff += '      #wait{font-weight: bold; display: none;}\n'
+        buff += '      #note{font-size: .85em;}\n'
+        buff += '      #button{padding: .5em 1em;}\n'
+        buff += '    -->\n'
+        buff += '  </style>\n'
+        buff += '  <script type="text/javascript">\n'
+        buff += '     function runsearch() {\n'
+        buff += '       document.getElementById(\'note\').style.display = \'none\';\n'
+        buff += '       document.getElementById(\'button\').style.display = \'none\';\n'
+        buff += '       document.getElementById(\'wait\').style.display = \'block\';\n'
+        buff += '       document.forms[0].submit();\n'
+        buff += '       return true;\n'
+        buff += '     }\n'
+        buff += '  </script>\n'
         buff += '</head>\n\n'
         
-        buff += '<body onload="document.forms[0].submit()">\n'
+        buff += '<body onload="runsearch()">\n'
         buff += '  <form action="%s" id="mainSearch" method="post">\n' % (config.profound['script'])
         buff += '    <div style="display:none;">\n\n'
         
@@ -823,9 +832,10 @@ class panelProfound(wx.MiniFrame):
         
         buff += '    <div id="info">\n'
         buff += '      <h1>mMass - ProFound Search</h1>\n'
-        buff += '      <p class="sending">Sending data to ProFound server.<br />Please wait...</p>\n'
-        buff += '      <p class="note">(Press Search button if data was not send automatically.)</p>\n'
-        buff += '      <p class="button"><input type="submit" value="Search" /></p>\n'
+        buff += '      <p id="sending">Sending data to ProFound &hellip;</p>\n'
+        buff += '      <p id="wait">Please wait &hellip;</p>\n'
+        buff += '      <p id="note">Press the <strong>Search</strong> button if data was not sent automatically.</p>\n'
+        buff += '      <p id="button"><input type="submit" value="Search" /></p>\n'
         buff += '    </div>\n\n'
         
         buff += '  </form>\n'
