@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -106,7 +106,6 @@ class panelProspector(wx.MiniFrame):
         self.query_butt.Bind(wx.EVT_BUTTON, self.onToolSelected)
         
         self.search_butt = wx.Button(panel, -1, "Search", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
-        self.search_butt.SetFont(wx.SMALL_FONT)
         self.search_butt.Bind(wx.EVT_BUTTON, self.onSearch)
         
         # pack elements
@@ -141,17 +140,17 @@ class panelProspector(wx.MiniFrame):
         
         # make sequence elements
         paramMSFitTaxonomy_label = wx.StaticText(panel, -1, "Taxonomy:")
-        self.paramMSFitTaxonomy_combo = wx.ComboBox(panel, -1, choices=[], size=(300, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
+        self.paramMSFitTaxonomy_choice = wx.Choice(panel, -1, choices=[], size=(300, mwx.CHOICE_HEIGHT))
         
         paramMSFitDatabase_label = wx.StaticText(panel, -1, "Database:")
-        self.paramMSFitDatabase_combo = wx.ComboBox(panel, -1, choices=[], size=(150, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
+        self.paramMSFitDatabase_choice = wx.Choice(panel, -1, choices=[], size=(150, mwx.CHOICE_HEIGHT))
         
         paramMSFitEnzyme_label = wx.StaticText(panel, -1, " Enzyme:")
-        self.paramMSFitEnzyme_combo = wx.ComboBox(panel, -1, choices=[], size=(130, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
+        self.paramMSFitEnzyme_choice = wx.Choice(panel, -1, choices=[], size=(130, mwx.CHOICE_HEIGHT))
         
         paramMSFitMiscleavages_label = wx.StaticText(panel, -1, " Miscl.:")
-        self.paramMSFitMiscleavages_combo = wx.ComboBox(panel, -1, choices=['0', '1', '2', '3', '4', '5', '6', '7', '8', '9'], size=(50, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.paramMSFitMiscleavages_combo.SetValue(str(config.prospector['msfit']['miscleavages']))
+        self.paramMSFitMiscleavages_choice = wx.Choice(panel, -1, choices=['0', '1', '2', '3', '4', '5', '6', '7', '8', '9'], size=(50, mwx.CHOICE_HEIGHT))
+        self.paramMSFitMiscleavages_choice.SetStringSelection(str(config.prospector['msfit']['miscleavages']))
         
         # make modifications elements
         self.paramMSFitFixedMods_label = wx.StaticText(panel, -1, "Fixed modifications:")
@@ -178,28 +177,28 @@ class panelProspector(wx.MiniFrame):
         
         paramMSFitPeptideTol_label = wx.StaticText(panel, -1, "Peptide tolerance:")
         self.paramMSFitPeptideTol_value = wx.TextCtrl(panel, -1, str(config.prospector['msfit']['peptideTol']), size=(50, -1), validator=mwx.validator('floatPos'))
-        self.paramMSFitPeptideTolUnits_combo = wx.ComboBox(panel, -1, choices=['Da','%','ppm'], size=(80, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.paramMSFitPeptideTolUnits_combo.SetValue(config.prospector['msfit']['peptideTolUnits'])
+        self.paramMSFitPeptideTolUnits_choice = wx.Choice(panel, -1, choices=['Da','%','ppm'], size=(80, mwx.CHOICE_HEIGHT))
+        self.paramMSFitPeptideTolUnits_choice.SetStringSelection(config.prospector['msfit']['peptideTolUnits'])
         
         paramMSFitMassType_label = wx.StaticText(panel, -1, "Mass type:")
-        self.paramMSFitMassType_combo = wx.ComboBox(panel, -1, choices=['Monoisotopic', 'Average'], size=(150, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.paramMSFitMassType_combo.SetValue(config.prospector['msfit']['massType'])
+        self.paramMSFitMassType_choice = wx.Choice(panel, -1, choices=['Monoisotopic', 'Average'], size=(150, mwx.CHOICE_HEIGHT))
+        self.paramMSFitMassType_choice.SetStringSelection(config.prospector['msfit']['massType'])
         
         paramMSFitInstrument_label = wx.StaticText(panel, -1, "Instrument:")
-        self.paramMSFitInstrument_combo = wx.ComboBox(panel, -1, choices=[], size=(150, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
+        self.paramMSFitInstrument_choice = wx.Choice(panel, -1, choices=[], size=(150, mwx.CHOICE_HEIGHT))
         
         # results elements
         paramMSFitMinMatches_label = wx.StaticText(panel, -1, "Min. matches required:")
-        self.paramMSFitMinMatches_combo = wx.ComboBox(panel, -1, choices=['1','2','3','4','5','6','7','8','9','10'], size=(60, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.paramMSFitMinMatches_combo.SetValue(str(config.prospector['msfit']['minMatches']))
+        self.paramMSFitMinMatches_choice = wx.Choice(panel, -1, choices=['1','2','3','4','5','6','7','8','9','10'], size=(60, mwx.CHOICE_HEIGHT))
+        self.paramMSFitMinMatches_choice.SetStringSelection(str(config.prospector['msfit']['minMatches']))
         
         paramMSFitMaxMods_label = wx.StaticText(panel, -1, "Max. mods:")
-        self.paramMSFitMaxMods_combo = wx.ComboBox(panel, -1, choices=['1','2','3','4'], size=(60, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.paramMSFitMaxMods_combo.SetValue(str(config.prospector['msfit']['maxMods']))
+        self.paramMSFitMaxMods_choice = wx.Choice(panel, -1, choices=['1','2','3','4'], size=(60, mwx.CHOICE_HEIGHT))
+        self.paramMSFitMaxMods_choice.SetStringSelection(str(config.prospector['msfit']['maxMods']))
         
         paramMSFitReport_label = wx.StaticText(panel, -1, "Report:")
-        self.paramMSFitReport_combo = wx.ComboBox(panel, -1, choices=['5','10','20','30','50'], size=(60, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.paramMSFitReport_combo.SetValue(str(config.prospector['msfit']['report']))
+        self.paramMSFitReport_choice = wx.Choice(panel, -1, choices=['5','10','20','30','50'], size=(60, mwx.CHOICE_HEIGHT))
+        self.paramMSFitReport_choice.SetStringSelection(str(config.prospector['msfit']['report']))
         
         # pack elements
         infoGrid = wx.GridBagSizer(mwx.GRIDBAG_VSPACE, mwx.GRIDBAG_HSPACE)
@@ -209,13 +208,13 @@ class panelProspector(wx.MiniFrame):
         
         sequenceGrid = wx.GridBagSizer(mwx.GRIDBAG_VSPACE, mwx.GRIDBAG_HSPACE)
         sequenceGrid.Add(paramMSFitTaxonomy_label, (0,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        sequenceGrid.Add(self.paramMSFitTaxonomy_combo, (0,1), (1,5), flag=wx.EXPAND)
+        sequenceGrid.Add(self.paramMSFitTaxonomy_choice, (0,1), (1,5), flag=wx.EXPAND)
         sequenceGrid.Add(paramMSFitDatabase_label, (1,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        sequenceGrid.Add(self.paramMSFitDatabase_combo, (1,1), flag=wx.EXPAND)
+        sequenceGrid.Add(self.paramMSFitDatabase_choice, (1,1), flag=wx.EXPAND)
         sequenceGrid.Add(paramMSFitEnzyme_label, (1,2), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        sequenceGrid.Add(self.paramMSFitEnzyme_combo, (1,3), flag=wx.EXPAND)
+        sequenceGrid.Add(self.paramMSFitEnzyme_choice, (1,3), flag=wx.EXPAND)
         sequenceGrid.Add(paramMSFitMiscleavages_label, (1,4), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        sequenceGrid.Add(self.paramMSFitMiscleavages_combo, (1,5))
+        sequenceGrid.Add(self.paramMSFitMiscleavages_choice, (1,5))
         sequenceGrid.AddGrowableCol(1)
         sequenceGrid.AddGrowableCol(3)
         
@@ -239,21 +238,21 @@ class panelProspector(wx.MiniFrame):
         massesGrid.Add(self.paramMSFitProteinPIHigh_value, (1,3), flag=wx.ALIGN_CENTER_VERTICAL)
         massesGrid.Add(paramMSFitPeptideTol_label, (2,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
         massesGrid.Add(self.paramMSFitPeptideTol_value, (2,1), flag=wx.ALIGN_CENTER_VERTICAL)
-        massesGrid.Add(self.paramMSFitPeptideTolUnits_combo, (2,3), (1,2), flag=wx.ALIGN_CENTER_VERTICAL)
+        massesGrid.Add(self.paramMSFitPeptideTolUnits_choice, (2,3), (1,2), flag=wx.ALIGN_CENTER_VERTICAL)
         
         massesGrid.Add(paramMSFitMassType_label, (0,5), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        massesGrid.Add(self.paramMSFitMassType_combo, (0,6), flag=wx.ALIGN_CENTER_VERTICAL)
+        massesGrid.Add(self.paramMSFitMassType_choice, (0,6), flag=wx.ALIGN_CENTER_VERTICAL)
         massesGrid.Add(paramMSFitInstrument_label, (1,5), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        massesGrid.Add(self.paramMSFitInstrument_combo, (1,6), flag=wx.ALIGN_CENTER_VERTICAL)
+        massesGrid.Add(self.paramMSFitInstrument_choice, (1,6), flag=wx.ALIGN_CENTER_VERTICAL)
         massesGrid.AddGrowableCol(4)
         
         resultsGrid = wx.GridBagSizer(mwx.GRIDBAG_VSPACE, mwx.GRIDBAG_HSPACE)
         resultsGrid.Add(paramMSFitMaxMods_label, (0,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        resultsGrid.Add(self.paramMSFitMaxMods_combo, (0,1), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
+        resultsGrid.Add(self.paramMSFitMaxMods_choice, (0,1), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
         resultsGrid.Add(paramMSFitMinMatches_label, (0,2), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        resultsGrid.Add(self.paramMSFitMinMatches_combo, (0,3), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
+        resultsGrid.Add(self.paramMSFitMinMatches_choice, (0,3), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
         resultsGrid.Add(paramMSFitReport_label, (0,4), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        resultsGrid.Add(self.paramMSFitReport_combo, (0,5), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
+        resultsGrid.Add(self.paramMSFitReport_choice, (0,5), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
         resultsGrid.AddGrowableCol(2)
         resultsGrid.AddGrowableCol(4)
         
@@ -287,17 +286,17 @@ class panelProspector(wx.MiniFrame):
         
         # make sequence elements
         paramMSTagTaxonomy_label = wx.StaticText(panel, -1, "Taxonomy:")
-        self.paramMSTagTaxonomy_combo = wx.ComboBox(panel, -1, choices=[], size=(300, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
+        self.paramMSTagTaxonomy_choice = wx.Choice(panel, -1, choices=[], size=(300, mwx.CHOICE_HEIGHT))
         
         paramMSTagDatabase_label = wx.StaticText(panel, -1, "Database:")
-        self.paramMSTagDatabase_combo = wx.ComboBox(panel, -1, choices=[], size=(150, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
+        self.paramMSTagDatabase_choice = wx.Choice(panel, -1, choices=[], size=(150, mwx.CHOICE_HEIGHT))
         
         paramMSTagEnzyme_label = wx.StaticText(panel, -1, " Enzyme:")
-        self.paramMSTagEnzyme_combo = wx.ComboBox(panel, -1, choices=[], size=(130, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
+        self.paramMSTagEnzyme_choice = wx.Choice(panel, -1, choices=[], size=(130, mwx.CHOICE_HEIGHT))
         
         paramMSTagMiscleavages_label = wx.StaticText(panel, -1, " Miscl.:")
-        self.paramMSTagMiscleavages_combo = wx.ComboBox(panel, -1, choices=['0', '1', '2', '3', '4', '5', '6', '7', '8', '9'], size=(50, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.paramMSTagMiscleavages_combo.SetValue(str(config.prospector['mstag']['miscleavages']))
+        self.paramMSTagMiscleavages_choice = wx.Choice(panel, -1, choices=['0', '1', '2', '3', '4', '5', '6', '7', '8', '9'], size=(50, mwx.CHOICE_HEIGHT))
+        self.paramMSTagMiscleavages_choice.SetStringSelection(str(config.prospector['mstag']['miscleavages']))
         
         # make modifications elements
         self.paramMSTagFixedMods_label = wx.StaticText(panel, -1, "Fixed modifications:")
@@ -315,34 +314,34 @@ class panelProspector(wx.MiniFrame):
         self.paramMSTagPeptideMass_value = wx.TextCtrl(panel, -1, "", size=(145, -1), validator=mwx.validator('float'))
         
         paramMSTagPeptideCharge_label = wx.StaticText(panel, -1, "Precursor charge:")
-        self.paramMSTagPeptideCharge_combo = wx.ComboBox(panel, -1, choices=['Automatic', '1', '2', '3', '4', '5', '6', '7', '8', '9', '10'], size=(145, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.paramMSTagPeptideCharge_combo.SetValue(str(config.prospector['mstag']['peptideCharge']))
+        self.paramMSTagPeptideCharge_choice = wx.Choice(panel, -1, choices=['Automatic', '1', '2', '3', '4', '5', '6', '7', '8', '9', '10'], size=(145, mwx.CHOICE_HEIGHT))
+        self.paramMSTagPeptideCharge_choice.SetStringSelection(str(config.prospector['mstag']['peptideCharge']))
         
         paramMSTagPeptideTol_label = wx.StaticText(panel, -1, "Precursor tolerance:")
         self.paramMSTagPeptideTol_value = wx.TextCtrl(panel, -1, str(config.prospector['mstag']['peptideTol']), size=(50, -1), validator=mwx.validator('floatPos'))
-        self.paramMSTagPeptideTolUnits_combo = wx.ComboBox(panel, -1, choices=['Da','%','ppm'], size=(80, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.paramMSTagPeptideTolUnits_combo.SetValue(config.prospector['mstag']['peptideTolUnits'])
+        self.paramMSTagPeptideTolUnits_choice = wx.Choice(panel, -1, choices=['Da','%','ppm'], size=(80, mwx.CHOICE_HEIGHT))
+        self.paramMSTagPeptideTolUnits_choice.SetStringSelection(config.prospector['mstag']['peptideTolUnits'])
         
         paramMSTagMSMSTol_label = wx.StaticText(panel, -1, "MS/MS tolerance:")
         self.paramMSTagMSMSTol_value = wx.TextCtrl(panel, -1, str(config.prospector['mstag']['msmsTol']), size=(50, -1), validator=mwx.validator('floatPos'))
-        self.paramMSTagMSMSTolUnits_combo = wx.ComboBox(panel, -1, choices=['Da','%','ppm'], size=(80, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.paramMSTagMSMSTolUnits_combo.SetValue(config.prospector['mstag']['msmsTolUnits'])
+        self.paramMSTagMSMSTolUnits_choice = wx.Choice(panel, -1, choices=['Da','%','ppm'], size=(80, mwx.CHOICE_HEIGHT))
+        self.paramMSTagMSMSTolUnits_choice.SetStringSelection(config.prospector['mstag']['msmsTolUnits'])
         
         paramMSTagMassType_label = wx.StaticText(panel, -1, "Mass type:")
-        self.paramMSTagMassType_combo = wx.ComboBox(panel, -1, choices=['Monoisotopic', 'Average'], size=(150, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.paramMSTagMassType_combo.SetValue(config.prospector['mstag']['massType'])
+        self.paramMSTagMassType_choice = wx.Choice(panel, -1, choices=['Monoisotopic', 'Average'], size=(150, mwx.CHOICE_HEIGHT))
+        self.paramMSTagMassType_choice.SetStringSelection(config.prospector['mstag']['massType'])
         
         paramMSTagInstrument_label = wx.StaticText(panel, -1, "Instrument:")
-        self.paramMSTagInstrument_combo = wx.ComboBox(panel, -1, choices=[], size=(150, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
+        self.paramMSTagInstrument_choice = wx.Choice(panel, -1, choices=[], size=(150, mwx.CHOICE_HEIGHT))
         
         # results elements
         paramMSTagMaxMods_label = wx.StaticText(panel, -1, "Max. mods:")
-        self.paramMSTagMaxMods_combo = wx.ComboBox(panel, -1, choices=['1','2','3','4'], size=(60, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.paramMSTagMaxMods_combo.SetValue(str(config.prospector['mstag']['maxMods']))
+        self.paramMSTagMaxMods_choice = wx.Choice(panel, -1, choices=['1','2','3','4'], size=(60, mwx.CHOICE_HEIGHT))
+        self.paramMSTagMaxMods_choice.SetStringSelection(str(config.prospector['mstag']['maxMods']))
         
         paramMSTagReport_label = wx.StaticText(panel, -1, "Report:")
-        self.paramMSTagReport_combo = wx.ComboBox(panel, -1, choices=['5','10','20','30','50'], size=(60, mwx.COMBO_HEIGHT), style=wx.CB_READONLY)
-        self.paramMSTagReport_combo.SetValue(str(config.prospector['mstag']['report']))
+        self.paramMSTagReport_choice = wx.Choice(panel, -1, choices=['5','10','20','30','50'], size=(60, mwx.CHOICE_HEIGHT))
+        self.paramMSTagReport_choice.SetStringSelection(str(config.prospector['mstag']['report']))
         
         # pack elements
         infoGrid = wx.GridBagSizer(mwx.GRIDBAG_VSPACE, mwx.GRIDBAG_HSPACE)
@@ -352,13 +351,13 @@ class panelProspector(wx.MiniFrame):
         
         sequenceGrid = wx.GridBagSizer(mwx.GRIDBAG_VSPACE, mwx.GRIDBAG_HSPACE)
         sequenceGrid.Add(paramMSTagTaxonomy_label, (0,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        sequenceGrid.Add(self.paramMSTagTaxonomy_combo, (0,1), (1,5), flag=wx.EXPAND)
+        sequenceGrid.Add(self.paramMSTagTaxonomy_choice, (0,1), (1,5), flag=wx.EXPAND)
         sequenceGrid.Add(paramMSTagDatabase_label, (1,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        sequenceGrid.Add(self.paramMSTagDatabase_combo, (1,1), flag=wx.EXPAND)
+        sequenceGrid.Add(self.paramMSTagDatabase_choice, (1,1), flag=wx.EXPAND)
         sequenceGrid.Add(paramMSTagEnzyme_label, (1,2), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        sequenceGrid.Add(self.paramMSTagEnzyme_combo, (1,3), flag=wx.EXPAND)
+        sequenceGrid.Add(self.paramMSTagEnzyme_choice, (1,3), flag=wx.EXPAND)
         sequenceGrid.Add(paramMSTagMiscleavages_label, (1,4), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        sequenceGrid.Add(self.paramMSTagMiscleavages_combo, (1,5))
+        sequenceGrid.Add(self.paramMSTagMiscleavages_choice, (1,5))
         sequenceGrid.AddGrowableCol(1)
         sequenceGrid.AddGrowableCol(3)
         
@@ -374,26 +373,26 @@ class panelProspector(wx.MiniFrame):
         massesGrid.Add(paramMSTagPeptideMass_label, (0,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
         massesGrid.Add(self.paramMSTagPeptideMass_value, (0,1), (1,2), flag=wx.ALIGN_CENTER_VERTICAL)
         massesGrid.Add(paramMSTagPeptideCharge_label, (1,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        massesGrid.Add(self.paramMSTagPeptideCharge_combo, (1,1), (1,2), flag=wx.ALIGN_CENTER_VERTICAL)
+        massesGrid.Add(self.paramMSTagPeptideCharge_choice, (1,1), (1,2), flag=wx.ALIGN_CENTER_VERTICAL)
         massesGrid.Add(paramMSTagPeptideTol_label, (2,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
         massesGrid.Add(self.paramMSTagPeptideTol_value, (2,1), flag=wx.ALIGN_CENTER_VERTICAL|wx.EXPAND)
-        massesGrid.Add(self.paramMSTagPeptideTolUnits_combo, (2,2), flag=wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_RIGHT)
+        massesGrid.Add(self.paramMSTagPeptideTolUnits_choice, (2,2), flag=wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_RIGHT)
         massesGrid.Add(paramMSTagMSMSTol_label, (3,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
         massesGrid.Add(self.paramMSTagMSMSTol_value, (3,1), flag=wx.ALIGN_CENTER_VERTICAL|wx.EXPAND)
-        massesGrid.Add(self.paramMSTagMSMSTolUnits_combo, (3,2), flag=wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_RIGHT)
+        massesGrid.Add(self.paramMSTagMSMSTolUnits_choice, (3,2), flag=wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_RIGHT)
         
         massesGrid.Add(paramMSTagMassType_label, (0,4), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        massesGrid.Add(self.paramMSTagMassType_combo, (0,5), flag=wx.ALIGN_CENTER_VERTICAL)
+        massesGrid.Add(self.paramMSTagMassType_choice, (0,5), flag=wx.ALIGN_CENTER_VERTICAL)
         massesGrid.Add(paramMSTagInstrument_label, (1,4), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        massesGrid.Add(self.paramMSTagInstrument_combo, (1,5), flag=wx.ALIGN_CENTER_VERTICAL)
+        massesGrid.Add(self.paramMSTagInstrument_choice, (1,5), flag=wx.ALIGN_CENTER_VERTICAL)
         massesGrid.AddGrowableCol(1)
         massesGrid.AddGrowableCol(3)
         
         resultsGrid = wx.GridBagSizer(mwx.GRIDBAG_VSPACE, mwx.GRIDBAG_HSPACE)
         resultsGrid.Add(paramMSTagMaxMods_label, (0,0), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        resultsGrid.Add(self.paramMSTagMaxMods_combo, (0,1), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
+        resultsGrid.Add(self.paramMSTagMaxMods_choice, (0,1), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
         resultsGrid.Add(paramMSTagReport_label, (0,2), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
-        resultsGrid.Add(self.paramMSTagReport_combo, (0,3), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
+        resultsGrid.Add(self.paramMSTagReport_choice, (0,3), flag=wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL)
         resultsGrid.AddGrowableCol(2)
         
         mainSizer = wx.BoxSizer(wx.VERTICAL)
@@ -667,21 +666,21 @@ class panelProspector(wx.MiniFrame):
             if config.prospector['common']['searchType'] == 'msfit':
                 
                 config.prospector['msfit']['title'] = self.paramMSFitTitle_value.GetValue()
-                config.prospector['msfit']['database'] = self.paramMSFitDatabase_combo.GetValue()
-                config.prospector['msfit']['taxonomy'] = self.paramMSFitTaxonomy_combo.GetValue()
-                config.prospector['msfit']['enzyme'] = self.paramMSFitEnzyme_combo.GetValue()
-                config.prospector['msfit']['miscleavages'] = self.paramMSFitMiscleavages_combo.GetValue()
+                config.prospector['msfit']['database'] = self.paramMSFitDatabase_choice.GetStringSelection()
+                config.prospector['msfit']['taxonomy'] = self.paramMSFitTaxonomy_choice.GetStringSelection()
+                config.prospector['msfit']['enzyme'] = self.paramMSFitEnzyme_choice.GetStringSelection()
+                config.prospector['msfit']['miscleavages'] = self.paramMSFitMiscleavages_choice.GetStringSelection()
                 config.prospector['msfit']['proteinMassLow'] = self.paramMSFitProteinMassLow_value.GetValue()
                 config.prospector['msfit']['proteinMassHigh'] = self.paramMSFitProteinMassHigh_value.GetValue()
                 config.prospector['msfit']['proteinPILow'] = self.paramMSFitProteinPILow_value.GetValue()
                 config.prospector['msfit']['proteinPIHigh'] = self.paramMSFitProteinPIHigh_value.GetValue()
                 config.prospector['msfit']['peptideTol'] = self.paramMSFitPeptideTol_value.GetValue()
-                config.prospector['msfit']['peptideTolUnits'] = self.paramMSFitPeptideTolUnits_combo.GetValue()
-                config.prospector['msfit']['massType'] = self.paramMSFitMassType_combo.GetValue()
-                config.prospector['msfit']['instrument'] = self.paramMSFitInstrument_combo.GetValue()
-                config.prospector['msfit']['minMatches'] = self.paramMSFitMinMatches_combo.GetValue()
-                config.prospector['msfit']['maxMods'] = self.paramMSFitMaxMods_combo.GetValue()
-                config.prospector['msfit']['report'] = self.paramMSFitReport_combo.GetValue()
+                config.prospector['msfit']['peptideTolUnits'] = self.paramMSFitPeptideTolUnits_choice.GetStringSelection()
+                config.prospector['msfit']['massType'] = self.paramMSFitMassType_choice.GetStringSelection()
+                config.prospector['msfit']['instrument'] = self.paramMSFitInstrument_choice.GetStringSelection()
+                config.prospector['msfit']['minMatches'] = self.paramMSFitMinMatches_choice.GetStringSelection()
+                config.prospector['msfit']['maxMods'] = self.paramMSFitMaxMods_choice.GetStringSelection()
+                config.prospector['msfit']['report'] = self.paramMSFitReport_choice.GetStringSelection()
                 
                 config.prospector['msfit']['fixedMods'] = []
                 fixedMods = self.paramMSFitFixedMods_listbox.GetStrings()
@@ -714,20 +713,20 @@ class panelProspector(wx.MiniFrame):
             if config.prospector['common']['searchType'] == 'mstag':
                 
                 config.prospector['mstag']['title'] = self.paramMSTagTitle_value.GetValue()
-                config.prospector['mstag']['database'] = self.paramMSTagDatabase_combo.GetValue()
-                config.prospector['mstag']['taxonomy'] = self.paramMSTagTaxonomy_combo.GetValue()
-                config.prospector['mstag']['enzyme'] = self.paramMSTagEnzyme_combo.GetValue()
-                config.prospector['mstag']['miscleavages'] = self.paramMSTagMiscleavages_combo.GetValue()
+                config.prospector['mstag']['database'] = self.paramMSTagDatabase_choice.GetStringSelection()
+                config.prospector['mstag']['taxonomy'] = self.paramMSTagTaxonomy_choice.GetStringSelection()
+                config.prospector['mstag']['enzyme'] = self.paramMSTagEnzyme_choice.GetStringSelection()
+                config.prospector['mstag']['miscleavages'] = self.paramMSTagMiscleavages_choice.GetStringSelection()
                 config.prospector['mstag']['peptideMass'] = self.paramMSTagPeptideMass_value.GetValue()
                 config.prospector['mstag']['peptideTol'] = self.paramMSTagPeptideTol_value.GetValue()
-                config.prospector['mstag']['peptideTolUnits'] = self.paramMSTagPeptideTolUnits_combo.GetValue()
+                config.prospector['mstag']['peptideTolUnits'] = self.paramMSTagPeptideTolUnits_choice.GetStringSelection()
                 config.prospector['mstag']['msmsTol'] = self.paramMSTagMSMSTol_value.GetValue()
-                config.prospector['mstag']['msmsTolUnits'] = self.paramMSTagMSMSTolUnits_combo.GetValue()
-                config.prospector['mstag']['massType'] = self.paramMSTagMassType_combo.GetValue()
-                config.prospector['mstag']['peptideCharge'] = self.paramMSTagPeptideCharge_combo.GetValue()
-                config.prospector['mstag']['instrument'] = self.paramMSTagInstrument_combo.GetValue()
-                config.prospector['mstag']['maxMods'] = self.paramMSTagMaxMods_combo.GetValue()
-                config.prospector['mstag']['report'] = self.paramMSTagReport_combo.GetValue()
+                config.prospector['mstag']['msmsTolUnits'] = self.paramMSTagMSMSTolUnits_choice.GetStringSelection()
+                config.prospector['mstag']['massType'] = self.paramMSTagMassType_choice.GetStringSelection()
+                config.prospector['mstag']['peptideCharge'] = self.paramMSTagPeptideCharge_choice.GetStringSelection()
+                config.prospector['mstag']['instrument'] = self.paramMSTagInstrument_choice.GetStringSelection()
+                config.prospector['mstag']['maxMods'] = self.paramMSTagMaxMods_choice.GetStringSelection()
+                config.prospector['mstag']['report'] = self.paramMSTagReport_choice.GetStringSelection()
                 
                 config.prospector['mstag']['fixedMods'] = []
                 fixedMods = self.paramMSTagFixedMods_listbox.GetStrings()
@@ -1234,43 +1233,43 @@ class panelProspector(wx.MiniFrame):
         }
         
         # update databases
-        self.paramMSFitDatabase_combo.Clear()
-        self.paramMSTagDatabase_combo.Clear()
+        self.paramMSFitDatabase_choice.Clear()
+        self.paramMSTagDatabase_choice.Clear()
         
         for item in self.currentParams['databases']:
-            self.paramMSFitDatabase_combo.Append(item)
-            self.paramMSTagDatabase_combo.Append(item)
+            self.paramMSFitDatabase_choice.Append(item)
+            self.paramMSTagDatabase_choice.Append(item)
         
         if config.prospector['msfit']['database'] in self.currentParams['databases']:
-            self.paramMSFitDatabase_combo.Select(self.currentParams['databases'].index(config.prospector['msfit']['database']))
+            self.paramMSFitDatabase_choice.Select(self.currentParams['databases'].index(config.prospector['msfit']['database']))
         if config.prospector['mstag']['database'] in self.currentParams['databases']:
-            self.paramMSTagDatabase_combo.Select(self.currentParams['databases'].index(config.prospector['mstag']['database']))
+            self.paramMSTagDatabase_choice.Select(self.currentParams['databases'].index(config.prospector['mstag']['database']))
         
         # update taxonomy
-        self.paramMSFitTaxonomy_combo.Clear()
-        self.paramMSTagTaxonomy_combo.Clear()
+        self.paramMSFitTaxonomy_choice.Clear()
+        self.paramMSTagTaxonomy_choice.Clear()
         
         for item in self.currentParams['taxonomy']:
-            self.paramMSFitTaxonomy_combo.Append(item)
-            self.paramMSTagTaxonomy_combo.Append(item)
+            self.paramMSFitTaxonomy_choice.Append(item)
+            self.paramMSTagTaxonomy_choice.Append(item)
         
         if config.prospector['msfit']['taxonomy'] in self.currentParams['taxonomy']:
-            self.paramMSFitTaxonomy_combo.Select(self.currentParams['taxonomy'].index(config.prospector['msfit']['taxonomy']))
+            self.paramMSFitTaxonomy_choice.Select(self.currentParams['taxonomy'].index(config.prospector['msfit']['taxonomy']))
         if config.prospector['mstag']['taxonomy'] in self.currentParams['taxonomy']:
-            self.paramMSTagTaxonomy_combo.Select(self.currentParams['taxonomy'].index(config.prospector['mstag']['taxonomy']))
+            self.paramMSTagTaxonomy_choice.Select(self.currentParams['taxonomy'].index(config.prospector['mstag']['taxonomy']))
         
         # update enzymes
-        self.paramMSFitEnzyme_combo.Clear()
-        self.paramMSTagEnzyme_combo.Clear()
+        self.paramMSFitEnzyme_choice.Clear()
+        self.paramMSTagEnzyme_choice.Clear()
         
         for item in self.currentParams['enzymes']:
-            self.paramMSFitEnzyme_combo.Append(item)
-            self.paramMSTagEnzyme_combo.Append(item)
+            self.paramMSFitEnzyme_choice.Append(item)
+            self.paramMSTagEnzyme_choice.Append(item)
         
         if config.prospector['msfit']['enzyme'] in self.currentParams['enzymes']:
-            self.paramMSFitEnzyme_combo.Select(self.currentParams['enzymes'].index(config.prospector['msfit']['enzyme']))
+            self.paramMSFitEnzyme_choice.Select(self.currentParams['enzymes'].index(config.prospector['msfit']['enzyme']))
         if config.prospector['mstag']['enzyme'] in self.currentParams['enzymes']:
-            self.paramMSTagEnzyme_combo.Select(self.currentParams['enzymes'].index(config.prospector['mstag']['enzyme']))
+            self.paramMSTagEnzyme_choice.Select(self.currentParams['enzymes'].index(config.prospector['mstag']['enzyme']))
         
         # update fixed modifications
         self.paramMSFitFixedMods_listbox.Clear()
@@ -1303,17 +1302,17 @@ class panelProspector(wx.MiniFrame):
                 self.paramMSTagVariableMods_listbox.Select(self.currentParams['variableMods'].index(item))
         
         # update instruments
-        self.paramMSFitInstrument_combo.Clear()
-        self.paramMSTagInstrument_combo.Clear()
+        self.paramMSFitInstrument_choice.Clear()
+        self.paramMSTagInstrument_choice.Clear()
         
         for item in self.currentParams['instruments']:
-            self.paramMSFitInstrument_combo.Append(item)
-            self.paramMSTagInstrument_combo.Append(item)
+            self.paramMSFitInstrument_choice.Append(item)
+            self.paramMSTagInstrument_choice.Append(item)
         
         if config.prospector['msfit']['instrument'] in self.currentParams['instruments']:
-            self.paramMSFitInstrument_combo.Select(self.currentParams['instruments'].index(config.prospector['msfit']['instrument']))
+            self.paramMSFitInstrument_choice.Select(self.currentParams['instruments'].index(config.prospector['msfit']['instrument']))
         if config.prospector['mstag']['instrument'] in self.currentParams['instruments']:
-            self.paramMSTagInstrument_combo.Select(self.currentParams['instruments'].index(config.prospector['mstag']['instrument']))
+            self.paramMSTagInstrument_choice.Select(self.currentParams['instruments'].index(config.prospector['mstag']['instrument']))
         
         # update modifications count
         self.onModificationSelected()
@@ -1330,21 +1329,31 @@ class panelProspector(wx.MiniFrame):
         buff += '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">\n'
         buff += '<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">\n'
         buff += '<head>\n'
-        buff += '  <title>Protein Prospector Search</title>\n'
-        buff += '   <style type="text/css">\n'
-        buff += '     <!--\n'
-        buff += '       body{text-align: center; margin: auto; font-size: .8em; font-family: Arial, Verdana, Geneva, Helvetica, sans-serif;}\n'
-        buff += '       #data{display:none;}\n'
-        buff += '       #info{width: 350px; margin: auto; margin-top: 5em; background-color: #f2f2f2; border: 1px solid #aaa;}\n'
-        buff += '       #info p.sending{font-weight: bold;}\n'
-        buff += '       #info p.note{font-size: .85em;}\n'
-        buff += '       #info p.button{padding: .5em 1em;}\n'
-        buff += '       h1{font-size: 1.3em; color: #fff; background-color: #aaa; margin: 0; padding: .2em;}\n'
-        buff += '     -->\n'
-        buff += '   </style>\n'
+        buff += '  <title>mMass - Protein Prospector Search</title>\n'
+        buff += '  <style type="text/css">\n'
+        buff += '    <!--\n'
+        buff += '      body{margin: auto; font-size: .8em; font-family: Arial, Verdana, Geneva, Helvetica, sans-serif; text-align: center; text-shadow: 1px 1px 1px #fff; color: #000; background-color: #f5f4f2;}\n'
+        buff += '      h1{margin: 0; padding: .7em; font-size: 1.4em; font-weight: bold; text-align: center; color: #999; border-bottom: 1px solid #ddd; }\n'
+        buff += '      #data{display:none;}\n'
+        buff += '      #info{ width: 350px; margin: auto; margin-top: 5em; background-color: #edece9; border-radius: 7px; border: 2px solid #fff; box-shadow: 0 0 5px rgba(0,0,0,.5);}\n'
+        buff += '      #sending{font-weight: bold}\n'
+        buff += '      #wait{font-weight: bold; display: none;}\n'
+        buff += '      #note{font-size: .85em;}\n'
+        buff += '      #button{padding: .5em 1em;}\n'
+        buff += '    -->\n'
+        buff += '  </style>\n'
+        buff += '  <script type="text/javascript">\n'
+        buff += '     function runsearch() {\n'
+        buff += '       document.getElementById(\'note\').style.display = \'none\';\n'
+        buff += '       document.getElementById(\'button\').style.display = \'none\';\n'
+        buff += '       document.getElementById(\'wait\').style.display = \'block\';\n'
+        buff += '       document.forms[0].submit();\n'
+        buff += '       return true;\n'
+        buff += '     }\n'
+        buff += '  </script>\n'
         buff += '</head>\n\n'
         
-        buff += '<body onload="document.forms[0].submit()">\n'
+        buff += '<body onload="runsearch()">\n'
         buff += '<body>\n'
         buff += '  <form action="%s" id="mainSearch" method="post">\n' % (config.prospector['common']['script'])
         buff += '    <div style="display:none;">\n\n'
@@ -1466,9 +1475,10 @@ class panelProspector(wx.MiniFrame):
         
         buff += '    <div id="info">\n'
         buff += '      <h1>mMass - Protein Prospector Search</h1>\n'
-        buff += '      <p class="sending">Sending data to Protein Prospector server.<br />Please wait...</p>\n'
-        buff += '      <p class="note">(Press Search button if data was not send automatically.)</p>\n'
-        buff += '      <p class="button"><input type="submit" value="Search" /></p>\n'
+        buff += '      <p id="sending">Sending data to Protein Prospector &hellip;</p>\n'
+        buff += '      <p id="wait">Please wait &hellip;</p>\n'
+        buff += '      <p id="note">Press the <strong>Search</strong> button if data was not sent automatically.</p>\n'
+        buff += '      <p id="button"><input type="submit" value="Search" /></p>\n'
         buff += '    </div>\n\n'
         
         buff += '  </form>\n'
