@@ -290,9 +290,9 @@ class panelSpectrum(wx.Panel):
         
         # convert normalized selection to real values
         if selection and config.spectrum['normalize']:
-            normalization = self.documents[self.currentDocument].spectrum.normalization()
-            y1 = (selection[1] * normalization[0]) + normalization[1]
-            y2 = (selection[3] * normalization[0]) + normalization[1]
+            f = self.documents[self.currentDocument].spectrum.normalization()
+            y1 = selection[1] * f
+            y2 = selection[3] * f
             selection = (selection[0], y1, selection[2], y2)
         
         # convert selection for offset documents
@@ -358,6 +358,7 @@ class panelSpectrum(wx.Panel):
         menu.Append(ID_viewSpectrumRulerDist, "Distance", "", wx.ITEM_CHECK)
         menu.Append(ID_viewSpectrumRulerPpm, "ppm", "", wx.ITEM_CHECK)
         menu.Append(ID_viewSpectrumRulerZ, "Charge", "", wx.ITEM_CHECK)
+        menu.Append(ID_viewSpectrumRulerMass, "Mass", "", wx.ITEM_CHECK)
         menu.Append(ID_viewSpectrumRulerArea, "Area", "", wx.ITEM_CHECK)
         
         # set values
@@ -365,14 +366,16 @@ class panelSpectrum(wx.Panel):
         menu.Check(ID_viewSpectrumRulerDist, bool('dist' in config.main['cursorInfo']))
         menu.Check(ID_viewSpectrumRulerPpm, bool('ppm' in config.main['cursorInfo']))
         menu.Check(ID_viewSpectrumRulerZ, bool('z' in config.main['cursorInfo']))
+        menu.Check(ID_viewSpectrumRulerMass, bool('mass' in config.main['cursorInfo']))
         menu.Check(ID_viewSpectrumRulerArea, bool('area' in config.main['cursorInfo']))
         
         # set events
-        self.Bind(wx.EVT_MENU, self.parent.onViewCursorInfo, id=ID_viewSpectrumRulerMz)
-        self.Bind(wx.EVT_MENU, self.parent.onViewCursorInfo, id=ID_viewSpectrumRulerDist)
-        self.Bind(wx.EVT_MENU, self.parent.onViewCursorInfo, id=ID_viewSpectrumRulerPpm)
-        self.Bind(wx.EVT_MENU, self.parent.onViewCursorInfo, id=ID_viewSpectrumRulerZ)
-        self.Bind(wx.EVT_MENU, self.parent.onViewCursorInfo, id=ID_viewSpectrumRulerArea)
+        self.Bind(wx.EVT_MENU, self.parent.onViewSpectrumRuler, id=ID_viewSpectrumRulerMz)
+        self.Bind(wx.EVT_MENU, self.parent.onViewSpectrumRuler, id=ID_viewSpectrumRulerDist)
+        self.Bind(wx.EVT_MENU, self.parent.onViewSpectrumRuler, id=ID_viewSpectrumRulerPpm)
+        self.Bind(wx.EVT_MENU, self.parent.onViewSpectrumRuler, id=ID_viewSpectrumRulerZ)
+        self.Bind(wx.EVT_MENU, self.parent.onViewSpectrumRuler, id=ID_viewSpectrumRulerMass)
+        self.Bind(wx.EVT_MENU, self.parent.onViewSpectrumRuler, id=ID_viewSpectrumRulerArea)
         
         self.PopupMenu(menu)
         menu.Destroy()
@@ -608,12 +611,26 @@ class panelSpectrum(wx.Panel):
         elif self.currentTool == 'labelenvelope' and position:
             charge = self.spectrumCanvas.getCharge()
             mass = mspy.mz(position[0], charge=0, currentCharge=charge*polarity)
-            format = 'm/z: %s   mass: %s   z: %s' % (mzFormat, mzFormat, '%d')
-            label = format % (position[0], mass, charge*polarity)
+            format = 'm/z: %s   z: %s   mass: %s' % (mzFormat, '%d', mzFormat)
+            label = format % (position[0] , charge*polarity, mass)
         
         # distance measurement
         elif distance and position:
             
+            # get charge and mass from distance
+            if distance[0] != 0 and abs(distance[0]) <= 2:
+                charge = abs(1/distance[0])
+                mass = mspy.mz(position[0], 0, round(charge)*polarity)
+            elif distance[0] > 10:
+                charge = abs(((position[0]-distance[0]) - 1.00728) / distance[0])
+                mass = mspy.mz(position[0], 0, round(charge)*polarity)
+            elif distance[0] < -10:
+                charge = abs((position[0] - 1.00728) / distance[0])
+                mass = mspy.mz(position[0], 0, round(charge+1)*polarity)
+            else:
+                charge = 0
+                mass = 0
+            
             if 'mz' in config.main['cursorInfo']:
                 format = 'm/z: %s   ' % mzFormat
                 label += format % position[0]
@@ -626,16 +643,18 @@ class panelSpectrum(wx.Panel):
                 format = 'ppm: %s   ' % ppmFormat
                 label += format % (1e6*distance[0]/position[0])
             
-            if 'z' in config.main['cursorInfo'] and distance[0]:
+            if 'z' in config.main['cursorInfo'] and charge:
                 if abs(distance[0]) > 10:
-                    charge = abs((min(position[0], position[0]-distance[0]) - 1.00728) / distance[0])
                     format = 'z: %s/%s   ' % (chargeFormat, chargeFormat)
                     label += format % ((charge+1)*polarity, charge*polarity)
                 else:
-                    charge = abs(1/distance[0])
                     format = 'z: %s   ' % chargeFormat
                     label += format % (charge*polarity)
             
+            if 'mass' in config.main['cursorInfo'] and mass > 0:
+                format = 'mass: %s   ' % mzFormat
+                label += format % mass
+            
             if 'area' in config.main['cursorInfo'] and self.currentDocument != None:
                 area = self.documents[self.currentDocument].spectrum.area(
                     minX = position[0]-distance[0],
@@ -651,8 +670,9 @@ class panelSpectrum(wx.Panel):
             format = 'm/z: %s   a.i.: %s' % (mzFormat, intFormat)
             label = format % (position[0], position[1])
         
-        # ensure label size to enable popup menu
-        label += ' ' * (100 - len(label))
+        # ensure some label size to enable popup menu
+        if len(label) < 100:
+            label += ' ' * (100 - len(label))
         
         # show info
         self.cursorInfo.SetLabel(label)
@@ -707,7 +727,7 @@ class panelSpectrum(wx.Panel):
         
         # set normalization
         if normalization:
-            obj.setNormalization(normalization[0], normalization[1])
+            obj.setNormalization(normalization)
         
         # add to container
         self.container[0] = obj
@@ -769,7 +789,7 @@ class panelSpectrum(wx.Panel):
         
         # set normalization
         if normalization:
-            obj.setNormalization(normalization[0], normalization[1])
+            obj.setNormalization(normalization)
         
         # add to container
         self.container[1] = obj
