@@ -90,6 +90,13 @@ class panelSpectrumGenerator(wx.MiniFrame):
         panel = mwx.bgrPanel(self, -1, images.lib['bgrToolbar'], size=(-1, mwx.TOOLBAR_HEIGHT))
         
         # make elements
+        peakShape_label = wx.StaticText(panel, -1, "Peak shape:")
+        peakShape_label.SetFont(wx.SMALL_FONT)
+        self.peakShape_choice = wx.Choice(panel, -1, choices=['Symmetrical', 'Asymmetrical'], size=(125, mwx.CHOICE_HEIGHT))
+        self.peakShape_choice.Select(0)
+        if config.spectrumGenerator['peakShape'] == 'gausslorentzian':
+            self.peakShape_choice.Select(1)
+        
         fwhm_label = wx.StaticText(panel, -1, "Default FWHM:")
         fwhm_label.SetFont(wx.SMALL_FONT)
         self.fwhm_value = wx.TextCtrl(panel, -1, str(config.spectrumGenerator['fwhm']), size=(60, -1), validator=mwx.validator('floatPos'))
@@ -98,7 +105,7 @@ class panelSpectrumGenerator(wx.MiniFrame):
         self.forceFwhm_check.SetFont(wx.SMALL_FONT)
         self.forceFwhm_check.SetValue(config.spectrumGenerator['forceFwhm'])
         
-        points_label = wx.StaticText(panel, -1, "Points per peak:")
+        points_label = wx.StaticText(panel, -1, "Points/peak:")
         points_label.SetFont(wx.SMALL_FONT)
         self.points_value = wx.TextCtrl(panel, -1, str(config.spectrumGenerator['points']), size=(60, -1), validator=mwx.validator('intPos'))
         
@@ -115,6 +122,9 @@ class panelSpectrumGenerator(wx.MiniFrame):
         # pack elements
         sizer = wx.BoxSizer(wx.HORIZONTAL)
         sizer.AddSpacer(mwx.CONTROLBAR_LSPACE)
+        sizer.Add(peakShape_label, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
+        sizer.Add(self.peakShape_choice, 0, wx.ALIGN_CENTER_VERTICAL)
+        sizer.AddSpacer(20)
         sizer.Add(fwhm_label, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
         sizer.Add(self.fwhm_value, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
         sizer.Add(self.forceFwhm_check, 0, wx.ALIGN_CENTER_VERTICAL)
@@ -126,7 +136,6 @@ class panelSpectrumGenerator(wx.MiniFrame):
         sizer.Add(self.noise_value, 0, wx.ALIGN_CENTER_VERTICAL)
         sizer.AddSpacer(20)
         sizer.AddStretchSpacer()
-        sizer.AddSpacer(40)
         sizer.Add(self.generate_butt, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 10)
         sizer.Add(self.apply_butt, 0, wx.ALIGN_CENTER_VERTICAL)
         sizer.AddSpacer(mwx.CONTROLBAR_RSPACE)
@@ -440,6 +449,11 @@ class panelSpectrumGenerator(wx.MiniFrame):
             config.spectrumGenerator['points'] = abs(int(self.points_value.GetValue()))
             config.spectrumGenerator['noise'] = abs(float(self.noise_value.GetValue()))
             config.spectrumGenerator['forceFwhm'] = self.forceFwhm_check.GetValue()
+            
+            config.spectrumGenerator['peakShape'] = 'gaussian'
+            if self.peakShape_choice.GetStringSelection() == 'Asymmetrical':
+                config.spectrumGenerator['peakShape'] = 'gausslorentzian'
+            
             return True
             
         except:
@@ -577,7 +591,8 @@ class panelSpectrumGenerator(wx.MiniFrame):
                 fwhm = config.spectrumGenerator['fwhm'],
                 points = config.spectrumGenerator['points'],
                 noise = config.spectrumGenerator['noise'],
-                forceFwhm = config.spectrumGenerator['forceFwhm']
+                forceFwhm = config.spectrumGenerator['forceFwhm'],
+                model = config.spectrumGenerator['peakShape'],
             )
             
             # make peak spectra
@@ -589,13 +604,33 @@ class panelSpectrumGenerator(wx.MiniFrame):
                 if peak.fwhm and not config.spectrumGenerator['forceFwhm']:
                     fwhm = peak.fwhm
                 
-                # calc peak
-                points = mspy.gaussian(
-                    x = peak.mz,
-                    minY = peak.base,
-                    maxY = peak.ai,
-                    fwhm = fwhm
-                )
+                # gaussian shape
+                if config.spectrumGenerator['peakShape'] == 'gaussian':
+                    points = mspy.gaussian(
+                        x = peak.mz,
+                        minY = peak.base,
+                        maxY = peak.ai,
+                        fwhm = fwhm
+                    )
+                
+                # lorentzian shape
+                elif config.spectrumGenerator['peakShape'] == 'lorentzian':
+                    points = mspy.lorentzian(
+                        x = peak.mz,
+                        minY = peak.base,
+                        maxY = peak.ai,
+                        fwhm = fwhm
+                    )
+                
+                # gauss-lorentzian shape
+                elif config.spectrumGenerator['peakShape'] == 'gausslorentzian':
+                    points = mspy.gausslorentzian(
+                        x = peak.mz,
+                        minY = peak.base,
+                        maxY = peak.ai,
+                        fwhm = fwhm
+                    )
+                
                 self.currentPeaks.append(points)
         
         # task canceled
