@@ -17,6 +17,7 @@
 
 # load libs
 import copy
+import math
 import numpy
 import time
 
@@ -78,7 +79,11 @@ def labelpoint(signal, mz, baseline=None):
     # get peak baseline and s/n
     base = 0.0
     sn = None
-    if baseline != None:
+    if baseline == None:
+        base, noise = mod_signal.noise(signal, x=mz)
+        if noise:
+            sn = (ai - base) / noise
+    else:
         idx = mod_signal.locate(baseline, mz)
         if (idx > 0) and (idx < len(baseline)):
             base = mod_signal.interpolate( (baseline[idx-1][0], baseline[idx-1][1]), (baseline[idx][0], baseline[idx][1]), x=mz)
@@ -611,7 +616,7 @@ def deconvolute(peaklist, massType=0):
     if buff:
         for peak in buff:
             peak.setsn(None)
-            peak.setai(peak.ai - peak.base)
+            peak.setai(peak.intensity)
             peak.setbase(0.)
     
     # update peaklist
