@@ -107,7 +107,7 @@ def boundaries(signal):
         raise ValueError, "Signal contains no data!"
     
     # calculate boundaries
-    return calculations.signal_boundaries(signal)
+    return calculations.signal_box(signal)
 # ----
 
 
@@ -127,7 +127,7 @@ def maxima(signal):
         return numpy.array([])
     
     # determine intensity
-    return calculations.signal_maxima(signal)
+    return calculations.signal_local_maxima(signal)
 # ----
 
 
@@ -204,13 +204,13 @@ def area(signal, minX=None, maxX=None, baseline=None):
         baseline (numpy array) - signal baseline
     """
     
-   # check signal type
+    # check signal type
     if not isinstance(signal, numpy.ndarray):
         raise TypeError, "Signal must be NumPy array!"
     if signal.dtype.name != 'float64':
         raise TypeError, "Signal data must be float64!"
     
-   # check baseline type
+    # check baseline type
     if baseline != None:
         if not isinstance(baseline, numpy.ndarray):
             raise TypeError, "Baseline must be NumPy array!"
@@ -221,6 +221,10 @@ def area(signal, minX=None, maxX=None, baseline=None):
     if len(signal) == 0:
         return 0.0
     
+    # check range
+    if minX != None and maxX != None and minX == maxX:
+        return 0.0
+    
     # crop data
     if minX != None and maxX != None:
         signal = crop(signal, minX, maxX)
@@ -275,7 +279,7 @@ def noise(signal, minX=None, maxX=None, x=None, window=0.1):
     if len(signal) == 0:
         return (0.0, 0.0)
     
-    # calculates noise
+    # calculate noise
     return calculations.signal_noise(signal)
 # ----
 
@@ -343,20 +347,6 @@ def baseline(signal, window=0.1, offset=0.):
 # ----
 
 
-def gaussian(x, minY, maxY, fwhm=0.1, points=500):
-    """Make Gaussian peak.
-        mz (float) - peak m/z value
-        minY (float) - min y-value
-        maxY (float) - max y-value
-        fwhm (float) - peak fwhm value
-        points (int) - number of points
-    """
-    
-    # make gaussian
-    return calculations.signal_gaussian(float(x), float(minY), float(maxY), float(fwhm), int(points))
-# ----
-
-
 def crop(signal, minX, maxX):
     """Crop signal to given x-range. New array is returned.
         signal (numpy array) - signal data points
