@@ -174,26 +174,26 @@ class scan:
             spectrumMin = numpy.minimum.reduce(self.profile)[1]
             peaklistMax = max([peak.ai for peak in self.peaklist])
             peaklistMin = min([peak.base for peak in self.peaklist])
-            shift = min(spectrumMin, peaklistMin)
-            scale = (max(spectrumMax, peaklistMax)-shift)/100
+            
+            return max(spectrumMax, peaklistMax)/100.
         
         # calculate range for spectrum only
         elif len(self.profile) > 0:
             spectrumMax = numpy.maximum.reduce(self.profile)[1]
             shift = numpy.minimum.reduce(self.profile)[1]
-            scale = (spectrumMax-shift)/100
+            
+            return spectrumMax/100.
         
         # calculate range for peaklist only
         elif len(self.peaklist) > 0:
             peaklistMax = max([peak.ai for peak in self.peaklist])
             shift = min([peak.base for peak in self.peaklist])
-            scale = (peaklistMax-shift)/100
+            
+            return peaklistMax/100.
         
         # no data
         else:
-            return 1., 0.
-        
-        return scale, shift
+            return 1.
     # ----
     
     
@@ -343,18 +343,17 @@ class scan:
         """Normalize profile and peaklist."""
         
         # get normalization params
-        normalization = self.normalization()
+        f = self.normalization()
         
         # normalize profile
         if len(self.profile) > 0:
-            self.profile -= numpy.array((0, normalization[1]))
-            self.profile /= numpy.array((1, normalization[0]))
+            self.profile /= numpy.array((1, f))
         
         # normalize peaklist
         if len(self.peaklist) > 0:
             for peak in self.peaklist:
-                peak.setai((peak.ai - normalization[1]) / normalization[0])
-                peak.setbase((peak.base - normalization[1]) / normalization[0])
+                peak.setai(peak.ai / f)
+                peak.setbase(peak.base / f)
             self.peaklist.reset()
         
         # clear buffers
