@@ -30,6 +30,7 @@ import obj_compound
 
 # load modules
 import mod_basics
+import mod_pattern
 
 
 # SEQUENCE OBJECT DEFINITION
@@ -464,16 +465,17 @@ class sequence:
     # ----
     
     
-    def pattern(self, fwhm=0.1, threshold=0.01, charge=0, agentFormula='H', agentCharge=1):
+    def pattern(self, fwhm=0.1, threshold=0.01, charge=0, agentFormula='H', agentCharge=1, real=True):
         """Get isotopic pattern."""
         
-        return mod_basics.pattern(
+        return mod_pattern.pattern(
             compound = self,
             fwhm = fwhm,
             threshold = threshold,
             charge = charge,
             agentFormula = agentFormula,
-            agentCharge = agentCharge
+            agentCharge = agentCharge,
+            real = real
         )
     # ----
     
