@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,11 +12,12 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
 import xml.sax
+import xml.dom.minidom
 import base64
 import zlib
 import struct
@@ -26,10 +27,12 @@ import numpy
 from copy import deepcopy
 
 # load stopper
-from stopper import CHECK_FORCE_QUIT
+from mod_stopper import CHECK_FORCE_QUIT
 
-# register essential objects
-import objects
+# load objects
+import obj_peak
+import obj_peaklist
+import obj_scan
 
 # compile basic patterns
 retentionPattern = re.compile('^PT((\d*\.?\d*)M)?((\d*\.?\d*)S)?$')
@@ -81,7 +84,7 @@ class parseMZXML():
     # ----
     
     
-    def getInfo(self):
+    def info(self):
         """Get document info."""
         
         # get preloaded data if available
@@ -107,7 +110,7 @@ class parseMZXML():
     # ----
     
     
-    def getScanlist(self):
+    def scanlist(self):
         """Get list of all scans in the document."""
         
         # use preloaded data if available
@@ -132,13 +135,19 @@ class parseMZXML():
     # ----
     
     
-    def getScan(self, scanID=None):
+    def scan(self, scanID=None):
         """Get spectrum from document."""
         
         # use preloaded data if available
         if self._scans and scanID in self._scans:
             data = self._scans[scanID]
         
+        # faster loading of single-scan documents
+        elif scanID == None:
+            parser = singleScanParser(self.path)
+            parser.parse()
+            data = parser.data
+        
         # parse file
         else:
             handler = scanHandler(scanID)
@@ -170,10 +179,10 @@ class parseMZXML():
         points = self._parsePoints(scanData)
         if scanData['spectrumType'] == 'discrete':
             for x, p in enumerate(points):
-                points[x] = objects.peak(p[0], p[1])
-            scan = objects.scan(peaks=objects.peaklist(points))
+                points[x] = obj_peak.peak(p[0], p[1])
+            scan = obj_scan.scan(peaklist=obj_peaklist.peaklist(points))
         else:
-            scan = objects.scan(points=points)
+            scan = obj_scan.scan(profile=points)
         
         # set metadata
         scan.title = scanData['title']
@@ -329,11 +338,6 @@ class scanlistHandler(xml.sax.handler.ContentHandler):
                 'spectrumType': self._spectrumType,
             }
             
-            # get spectrum type
-            attribute = attrs.get('centroided', False)
-            if attribute and attribute != '0':
-                scan['centroided'] = 'discrete'
-            
             # get ms level
             attribute = attrs.get('msLevel', 1)
             if attribute:
@@ -354,7 +358,7 @@ class scanlistHandler(xml.sax.handler.ContentHandler):
             # get scan retention time
             attribute = attrs.get('retentionTime', None)
             if attribute != None:
-                scan['retentionTime'] = self._convertRetentionTime(attribute)
+                scan['retentionTime'] = _convertRetentionTime(attribute)
             
             # get low m/z
             attribute = attrs.get('lowMz', None)
@@ -430,25 +434,6 @@ class scanlistHandler(xml.sax.handler.ContentHandler):
     # ----
     
     
-    def _convertRetentionTime(self, retention):
-        """Convert retention time to seconds."""
-        
-        # match retention
-        match = retentionPattern.match(retention)
-        if not match:
-            return None
-        
-        # convert to seconds
-        seconds = 0
-        if match.group(2):
-            seconds += float(match.group(2))*60
-        if match.group(4):
-            seconds += float(match.group(4))
-        
-        return seconds
-    # ----
-    
-    
 
 class scanHandler(xml.sax.handler.ContentHandler):
     """Get scan data."""
@@ -514,11 +499,6 @@ class scanHandler(xml.sax.handler.ContentHandler):
                     'precision': None,
                 }
                 
-                # get spectrum type
-                attribute = attrs.get('centroided', False)
-                if attribute and attribute != '0':
-                    self.data['centroided'] = 'discrete'
-                
                 # get ms level
                 attribute = attrs.get('msLevel', 1)
                 if attribute:
@@ -539,7 +519,7 @@ class scanHandler(xml.sax.handler.ContentHandler):
                 # get scan retention time
                 attribute = attrs.get('retentionTime', None)
                 if attribute != None:
-                    self.data['retentionTime'] = self._convertRetentionTime(attribute)
+                    self.data['retentionTime'] = _convertRetentionTime(attribute)
                 
                 # get low m/z
                 attribute = attrs.get('lowMz', None)
@@ -645,25 +625,6 @@ class scanHandler(xml.sax.handler.ContentHandler):
     # ----
     
     
-    def _convertRetentionTime(self, retention):
-        """Convert retention time to seconds."""
-        
-        # match retention
-        match = retentionPattern.match(retention)
-        if not match:
-            return None
-        
-        # convert to seconds
-        seconds = 0
-        if match.group(2):
-            seconds += float(match.group(2))*60
-        if match.group(4):
-            seconds += float(match.group(4))
-        
-        return seconds
-    # ----
-    
-    
 
 class runHandler(xml.sax.handler.ContentHandler):
     """Get whole run."""
@@ -723,11 +684,6 @@ class runHandler(xml.sax.handler.ContentHandler):
                 'precision': None,
             }
             
-            # get spectrum type
-            attribute = attrs.get('centroided', False)
-            if attribute and attribute != '0':
-                scan['centroided'] = 'discrete'
-            
             # get ms level
             attribute = attrs.get('msLevel', 1)
             if attribute:
@@ -748,7 +704,7 @@ class runHandler(xml.sax.handler.ContentHandler):
             # get scan retention time
             attribute = attrs.get('retentionTime', None)
             if attribute != None:
-                scan['retentionTime'] = self._convertRetentionTime(attribute)
+                scan['retentionTime'] = _convertRetentionTime(attribute)
             
             # get low m/z
             attribute = attrs.get('lowMz', None)
@@ -852,22 +808,172 @@ class runHandler(xml.sax.handler.ContentHandler):
     # ----
     
     
-    def _convertRetentionTime(self, retention):
-        """Convert retention time to seconds."""
+
+class singleScanParser():
+    """Faster loading of single-scan documents."""
+    
+    def __init__(self, path):
         
-        # match retention
-        match = retentionPattern.match(retention)
-        if not match:
-            return None
+        self.path = path
+        self.data = None
+        self._parsedData = None
+    # ----
+    
+    
+    def parse(self):
+        """Parse document."""
         
-        # convert to seconds
-        seconds = 0
-        if match.group(2):
-            seconds += float(match.group(2))*60
-        if match.group(4):
-            seconds += float(match.group(4))
+        # read xml
+        try:
+            doc = file(self.path)
+            rawData = doc.read()
+            doc.close()
+            self._parsedData = xml.dom.minidom.parseString(rawData)
+        except:
+            self.data = None
+            return
         
-        return seconds
+        # init data
+        self.data = {
+                'title': '',
+                'scanNumber': None,
+                'parentScanNumber': None,
+                'msLevel': None,
+                'pointsCount': None,
+                'polarity': None,
+                'retentionTime': None,
+                'lowMZ': None,
+                'highMZ': None,
+                'basePeakMZ': None,
+                'basePeakIntensity': None,
+                'totIonCurrent': None,
+                'precursorMZ': None,
+                'precursorIntensity': None,
+                'precursorCharge': None,
+                'spectrumType': 'unknown',
+                
+                'points': None,
+                'byteOrder': None,
+                'compression': None,
+                'precision': None,
+        }
+        
+        # parse xml
+        self.handleSpectrum()
+        self.handleMetadata()
+    # ----
+    
+    
+    def handleSpectrum(self):
+        """Get spectrum data."""
+        
+        # get data type
+        dataProcessingTags = self._parsedData.getElementsByTagName('dataProcessing')
+        if dataProcessingTags:
+            centroided = dataProcessingTags[0].getAttribute('centroided')
+            if centroided and centroided != '0':
+                self.data['spectrumType'] = 'discrete'
+        
+        # get data
+        peaksTags = self._parsedData.getElementsByTagName('peaks')
+        if peaksTags:
+            
+            # get byte order
+            self.data['byteOrder'] = peaksTags[0].getAttribute('byteOrder')
+            
+            # get compression
+            attribute = peaksTags[0].getAttribute('compressionType')
+            if attribute and attribute != 'none':
+                self.data['compression'] = attribute
+            
+            # get precision
+            attribute = peaksTags[0].getAttribute('precision')
+            if attribute:
+                self.data['precision'] = int(attribute)
+            
+            # get array data
+            self.data['points'] = ''
+            for node in peaksTags[0].childNodes:
+                if node.nodeType == node.TEXT_NODE:
+                    self.data['points'] += node.data
+    # ----
+    
+    
+    def handleMetadata(self):
+        """Get metadata."""
+        
+        # get scan meta
+        scanTags = self._parsedData.getElementsByTagName('scan')
+        if scanTags:
+            
+            # get ms level
+            attribute = scanTags[0].getAttribute('msLevel')
+            if attribute:
+                self.data['msLevel'] = int(attribute)
+            
+            # get number of points
+            attribute = scanTags[0].getAttribute('peaksCount')
+            if attribute:
+                self.data['pointsCount'] = int(attribute)
+            
+            # get polarity
+            attribute = scanTags[0].getAttribute('polarity')
+            if attribute in ('positive', 'Positive', '+'):
+                self.data['polarity'] = 1
+            elif attribute in ('negative', 'Negative', '-'):
+                self.data['polarity'] = -1
+            
+            # get scan retention time
+            attribute = scanTags[0].getAttribute('retentionTime')
+            if attribute:
+                self.data['retentionTime'] = _convertRetentionTime(attribute)
+            
+            # get low m/z
+            attribute = scanTags[0].getAttribute('lowMz')
+            if attribute:
+                self.data['lowMZ'] = float(attribute)
+            
+            # get high m/z
+            attribute = scanTags[0].getAttribute('highMz')
+            if attribute:
+                self.data['highMZ'] = float(attribute)
+            
+            # get base peak m/z
+            attribute = scanTags[0].getAttribute('basePeakMz')
+            if attribute:
+                self.data['basePeakMZ'] = float(attribute)
+            
+            # get base peak intensity
+            attribute = scanTags[0].getAttribute('basePeakIntensity')
+            if attribute:
+                self.data['basePeakIntensity'] = float(attribute)
+            
+            # get total ion current
+            attribute = scanTags[0].getAttribute('totIonCurrent')
+            if attribute:
+                self.data['totIonCurrent'] = float(attribute)
+        
+        # get precursor
+        precursorMzTags = self._parsedData.getElementsByTagName('precursorMz')
+        if precursorMzTags:
+            
+            # get precursor intensity
+            attribute = precursorMzTags[0].getAttribute('precursorIntensity')
+            if attribute:
+                self.data['precursorIntensity'] = float(attribute)
+            
+            # get precursor charge
+            attribute = precursorMzTags[0].getAttribute('precursorCharge')
+            if attribute:
+                self.data['precursorCharge'] = int(attribute)
+            
+            # get precursor m/z
+            precursorMZ = ''
+            for node in precursorMzTags[0].childNodes:
+                if node.nodeType == node.TEXT_NODE:
+                    precursorMZ += node.data
+            if precursorMZ:
+                self.data['precursorMZ'] = float(precursorMZ)
     # ----
     
     
@@ -877,3 +983,22 @@ class stopParsing(Exception):
     pass
 
 
+def _convertRetentionTime(retention):
+    """Convert retention time to seconds."""
+    
+    # match retention
+    match = retentionPattern.match(retention)
+    if not match:
+        return None
+    
+    # convert to seconds
+    seconds = 0
+    if match.group(2):
+        seconds += float(match.group(2))*60
+    if match.group(4):
+        seconds += float(match.group(4))
+    
+    return seconds
+# ----
+
+
